<?php
// $Id$

/**
 * Constructs an XML output for generating exports of contract data.
 */
class ContractXML {

	function __construct() {
		$this->store = new trafficStorage();
	}

    public function actions() {
        switch(globalize('action')) {
            default:
				break;
        }
    }

	function appendResult($doc,$query,$obj,$parent) {
		$result = sysdb::query($query);
        if (sizeof($result) <= 0) {
			return false;
		} else {
			while ($line = sysdb::fetch_assoc($result)) {
				$parent->appendChild($object = $doc->createElement($obj));
				foreach ($line as $key=>$value) {
					if ($key == 'id') {
						$object->setAttribute('id', $value);
					} else if ($key == 'refid') {
						$object->setAttribute('refid', $value);
					} else {
						$object->appendChild($column = $doc->createElement($key));
						$column->appendChild($doc->createTextNode($value));
					}
				}
				return $object;
			}
		}
	}

    public function download($svg,$id) {
		if ($svg != '') {
			$mimetype = 'image/svg+xml';
			$filename = 'contract_'.$id.'_export';
			$ext = mime2extension($mimetype);
			$file = $filename.'.'.$ext;
			// // File download.
			// header('Content-Description: File Transfer');
			// header('Content-Type: '.$mimetype);
			// header("Content-Disposition: attachment; filename=\"$file\"");
			// header('Content-Transfer-Encoding: binary');
			// header('Expires: 0');
			// header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
			// header('Pragma: public');

			// File view in browser.
			//header('Content-Disposition: inline; filename="'.$file.'";');
			header("Content-Disposition: inline; filename=\"{$file}\";");
			header("Content-Type: ".$mimetype);
//			header("Content-length: ".strlen($data));

			print $svg;
			exit;
		} else {
			state::setMessage('warning', 'File did not export properly: could not download file.' );
			module::forward_to_script('',array('item'=>'Contract','action'=>'view','id'=>$id));
		}
    }

	function getContractSVG($contractID) {
		// Get source data.
		if ($contractID != '') {
			$xml = $this->getContractXML($contractID);
		} else {
			state::setMessage('error', 'Cannot export: could not decide which contract to export. ');
			exit;
		}

		// Determine the first scheduled spot's dateTime to use as the start date.
		$query = <<<EOQ
			SELECT MIN(S.dateTime) as startDateTime,
				MAX(S.dateTime) as endDateTime
			FROM ({$this->store->table_traffic_spot} S,
				{$this->store->table_traffic_campaignaudio} A
			)
			WHERE A.contractID = '$contractID'
			AND S.mediaID = A.mediaID
EOQ;
		$result = sysdb::query($query);
		$line = sysdb::fetch_assoc($result);
		$startDateTime = $line['startDateTime'];
		$endDateTime = $line['endDateTime'];
		//$startDateTime = sysdb::queryOne($query);

		if (sizeof($startDateTime) <= 0) {
			state::setMessage('warning', 'No spots scheduled. ' );
			exit;
		} else {
			$startDate = date('Y-m-d', strtotime($startDateTime));
			$endDate = date('Y-m-d', strtotime($endDateTime));
			
			// Merge with the template to generate the output.
			if ($xml != false) {
				$svg = $this->xsl_transform(utf8_decode($xml), ROOT_COMPONENTS.'traffic/templates/contract.xsl', array('startDate'=>$startDate, 'endDate'=>$endDate, 'slotTime'=>'06:00:00'));
			} else {
				state::setMessage('error', 'Cannot export: contract could not extract source data. ');
				exit;
			}

			// Send output to the user.
			if ($svg != false) {
				$this->download($svg,$contractID);
			} else {
				state::setMessage('error', 'Cannot export: contract could not be generated. ');
				exit;
			}
		}
	}

	/**
	 * Fetches data related to a contract id and builds and returns an XML tree.
	 */
	function getContractXML($contractID) {
		$xml = '';

		// Get initial parent client id.
		$query = <<<EOQ
			SELECT O.clientID
			FROM ({$this->store->table_traffic_contract} O)
			WHERE O.contractID = '$contractID'
EOQ;
		$clientID = sysdb::queryOne($query);

		$doc = new DOMDocument('1.0');
		$doc->formatOutput = true;
		$traffic = $doc->appendChild($doc->createElement('traffic'));

		// Fetch client details.
		$query = <<<EOQ
			SELECT C.clientID as id,
				C.name,
				D.address,
				D.city,
				D.state,
				D.postcode,
				D.landline,
				D.fax,
				D.mobile,
				D.email
			FROM ({$this->store->table_traffic_client} C,
				{$this->store->table_detail} D)
			WHERE C.clientID = '$clientID'
			and C.actorID = D.actorID
EOQ;
		$result = self::appendResult($doc,$query,'client',$traffic);
		if (is_object($result)) {
			$client = $traffic->appendChild($result);
		}

		// Fetch contract details.
		$query = <<<EOQ
			SELECT O.contractID as id,
				O.clientID as refid,
				O.name,
				O.price,
				O.priceGST,
				O.createdDateTime,
				O.audioPurchased,
				O.spotsPurchased,
				O.stationPresentsStatus,
				O.services,
				O.notes
			FROM ({$this->store->table_traffic_contract} O)
			WHERE O.contractID = '$contractID'
EOQ;
		$result = self::appendResult($doc,$query,'contract',$client);
		if (is_object($result)) {
			$contract = $client->appendChild($result);
		}

		// Fetch campaign details.
		$query = <<<EOQ
			SELECT M.campaignID as id,
				M.contractID as refid,
				M.name,
				M.startDate,
				M.endDate
			FROM ({$this->store->table_traffic_campaign} M)
			WHERE M.contractID = '$contractID'
EOQ;
		$result = self::appendResult($doc,$query,'campaign',$contract);
		if (is_object($result)) {
			$campaign = $contract->appendChild($result);
		}

		// Fetch campaign audio details.
		// TODO: This is not pulling productType data properly. It just pulls the productType for the first type found in the contract tree structure.
		//  But because the contract can only display one PT, this is not such a big issue.
		$query = <<<EOQ
			SELECT A.campaignAudioID as id,
				A.campaignID as refid,
				A.name as name,
				A.startDate as startDate,
				A.endDate as endDate,
				(SELECT S.name
					FROM ({$this->store->table_traffic_campaignaudioproducttype} R,
						{$this->store->table_traffic_producttype} S,
						{$this->store->table_traffic_campaignaudio} A)
					WHERE A.contractID = '$contractID'
					AND R.campaignAudioID = A.campaignAudioID
					AND S.productTypeID = R.productTypeID
					LIMIT 1
				) as productType
			FROM ({$this->store->table_traffic_campaignaudio} A)
			WHERE A.contractID = '$contractID'
EOQ;
		// As Audio requires nested spots, this append data does not use the appendResult() function.
		$result = sysdb::query($query);
		while ($line = sysdb::fetch_assoc($result)) {
			$campaign->appendChild($campaignAudio = $doc->createElement('campaignAudio'));
			foreach ($line as $key=>$value) {
				if ($key == 'id') {
					$id = $line['id'];
					$campaignAudio->setAttribute('id', $value);
				} else if ($key == 'refid') {
					$campaignAudio->setAttribute('refid', $value);
				} else {
					$campaignAudio->appendChild($column = $doc->createElement($key));
					$column->appendChild($doc->createTextNode($value));
				}
			}
			// Fetch spot details.
			$query2 = <<<EOQ
                SELECT S.spotID as id,
					A.campaignAudioID as refid,
					S.dateTime as dateTime
                FROM ({$this->store->table_traffic_spot} S,
					{$this->store->table_traffic_campaignaudio} A)
                WHERE A.campaignAudioID = '$id'
                AND S.mediaID = A.mediaID
EOQ;
			$result2 = sysdb::query($query2);
			while ($line2 = sysdb::fetch_assoc($result2)) {
				$campaignAudio->appendChild($spot = $doc->createElement('spot'));
				foreach ($line2 as $key=>$value) {
					if ($key == 'id') {
						$spot->setAttribute('id', $value);
					} else if ($key == 'refid') {
						$spot->setAttribute('refid', $value);
					} else {
						$spot->setAttribute($key, $value);
//						$spot->appendChild($column = $doc->createElement($key));
//						$column->appendChild($doc->createTextNode($value));
//						$spot->appendChild($doc->createTextNode('x'));
					}
				}
			}
		}


		// Fetch campaign promo details.
		$query = <<<EOQ
			SELECT A.campaignPromotionID as id,
				A.campaignID as refid,
				A.name as name
			FROM ({$this->store->table_traffic_campaignpromotion} A)
			WHERE A.contractID = '$contractID'
EOQ;
		// As Audio requires nested spots, this append data does not use the appendResult() function.
		$result = sysdb::query($query);
		while ($line = sysdb::fetch_assoc($result)) {
			$campaign->appendChild($campaignPromotion = $doc->createElement('campaignPromotion'));
			foreach ($line as $key=>$value) {
				if ($key == 'id') {
					$id = $line['id'];
					$campaignPromotion->setAttribute('id', $value);
				} else if ($key == 'refid') {
					$campaignPromotion->setAttribute('refid', $value);
				} else {
					$campaignPromotion->appendChild($column = $doc->createElement($key));
					$column->appendChild($doc->createTextNode($value));
				}
			}
			// Fetch spot details.
			$query2 = <<<EOQ
                SELECT S.spotID as id,
					A.campaignPromotionID as refid,
					S.dateTime as dateTime
                FROM ({$this->store->table_traffic_spot} S,
					{$this->store->table_traffic_campaignpromotion} A)
                WHERE A.campaignPromotionID = '$id'
                AND S.mediaID = A.mediaID
EOQ;
			$result2 = sysdb::query($query2);
			while ($line2 = sysdb::fetch_assoc($result2)) {
				$campaignPromotion->appendChild($spot = $doc->createElement('spot'));
				foreach ($line2 as $key=>$value) {
					if ($key == 'id') {
						$spot->setAttribute('id', $value);
					} else if ($key == 'refid') {
						$spot->setAttribute('refid', $value);
					} else {
						$spot->setAttribute($key, $value);
//						$spot->appendChild($column = $doc->createElement($key));
//						$column->appendChild($doc->createTextNode($value));
//						$spot->appendChild($doc->createTextNode('x'));
					}
				}
			}
		}



		// Fetch client sector details.
		$query = <<<EOQ
			SELECT R.sectorID as id,
				R.clientID as refid,
				S.name
			FROM ({$this->store->table_traffic_clientsector} R,
				{$this->store->table_traffic_sector} S,
				{$this->store->table_traffic_client} C)
			WHERE C.clientID = '$clientID'
			AND R.clientID = C.clientID
			AND S.sectorID = R.sectorID
EOQ;
		$result = self::appendResult($doc,$query,'sector',$client);
		if (is_object($result)) {
			$sector = $client->appendChild($result);
		}

		// Fetch client rep details.
		$query = <<<EOQ
			SELECT R.clientRepID as id,
				D.firstName,
				D.lastName
			FROM ({$this->store->table_traffic_contractclientrep} R,
				{$this->store->table_traffic_clientrep} C,
				{$this->store->table_detail} D,
				{$this->store->table_traffic_contract} O)
			WHERE O.contractID = '$contractID'
			AND R.contractID = O.contractID
			AND C.clientRepID = R.clientRepID
			AND C.actorID = D.actorID
EOQ;

		$result = self::appendResult($doc,$query,'clientRep',$traffic);
		if (is_object($result)) {
			$clientRep = $traffic->appendChild($result);
		}

		// Fetch sales rep details.
		$query = <<<EOQ
			SELECT R.salesRepID as id,
				D.firstName,
				D.lastName
			FROM ({$this->store->table_traffic_contractsalesrep} R,
				{$this->store->table_traffic_salesrep} S,
				{$this->store->table_detail} D,
				{$this->store->table_traffic_contract} O)
			WHERE O.contractID = '$contractID'
			AND R.contractID = O.contractID
			AND S.salesRepID = R.salesRepID
			AND S.actorID = D.actorID
EOQ;
		$result = self::appendResult($doc,$query,'salesRep',$traffic);
		if (is_object($result)) {
			$salesRep = $traffic->appendChild($result);
		}

		$traffic->appendChild($orgTrading = $doc->createElement('ORG_TRADING'));
		$orgTrading->appendChild($doc->createTextNode(ORG_TRADING));

		$traffic->appendChild($orgName = $doc->createElement('ORG_NAME'));
		$orgName->appendChild($doc->createTextNode(ORG_NAME));

		// Compile the XML output.
		$xml = $doc->saveXML();

		return ($xml);
	}

	function xsl_transform($xmldata,$xslfile,$params) {
		// // Create an XSLT processor
		// $doc = new DOMDocument();
		// $xsl = new XSLTProcessor();

		// // Perform the transformation
		// $doc->load($xslfile);
		// $xsl->importStyleSheet($doc);
		// $xsl->formatOutput = true;
		// // $xsl->resolveExternals = false;

		// if ($params != '')
			// $xsl->setParameter('',$params);

		// $doc->loadXML($xmldata);
		// $xml = $xsl->transformToXML($doc);

		// Create an XSLT processor
		$xml = new DOMDocument();
		$xsl = new DOMDocument();

		// Perform the transformation
		$xsl->load($xslfile);

		$proc = new XSLTProcessor();
		$proc->importStyleSheet($xsl);

		if ($params != '')
			$proc->setParameter('',$params);

		$xml->loadXML($xmldata);
		$xml = $proc->transformToXML($xml);

		return($xml);
	}

}
