<?php
// $Id$

/**
 * Manages the display and management of spots within a timeslot (slot).
 */
class Traffic {
	var $store;

	/**
	 * Automatically loads core and component storage parameters.
	 */
	function __construct() {
		$this->store = new trafficStorage();
	}

    private $info = array('display_modes'=> array('displayGridByHour'));

    public function get_info($key) {
        if(isset($this->info[$key])) {
           return $this->info[$key];
        } else {
           return false;
        }
    }

    public function actions() {
        switch(globalize('action')) {
            case 'example': $this->example(globalize('params')); break;
            case 'reorder': $this->reprioritizeSpots(globalize('spotID'),globalize('shift_value')); break;
        }
    }

    public function form($doc,$id='') {

       // form, returns FORM dom document

    }

    public function view($doc,$id) {

       // view, returns VIEW dom document

    }

    public function displayGridByHour($doc) {

		global $module_parameter;

		$moduleID = globalize('moduleID');
        $mode = globalize('mode','All');
		$action = globalize('action');
        $clientID = globalize('clientID');
        $contractID = globalize('contractID');
        $campaignID = globalize('campaignID');
        $campaignAudioID = globalize('campaignAudioID');

		// Check to see if a max hourly time is set as a module parameter.
		if (isset($module_parameter['maxTimePerHour'])) {
			$maxtime = $module_parameter['maxTimePerHour'];
		} else {
			$maxtime = 300;
		}

		$objects = array('clientID'=>$clientID,
						'contractID'=>$contractID,
						'campaignID'=>$campaignID,
						'campaignAudioID'=>$campaignAudioID
						);
		foreach ($objects as $object=>$objectID) {
			if ($objectID != '') {
				// Determine the first scheduled spot's dateTime to use as the start date.
				$query = <<<EOQ
					SELECT MIN(S.{$this->store->field_spot_dateTime}) AS startDate
					FROM ({$this->store->table_traffic_spot} S,
						{$this->store->table_traffic_campaignaudio} A
					)
					WHERE A.$object = $objectID
					AND S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
EOQ;
				$startDate = sysdb::queryOne($query);

				// Check if the retrieved spot date exists, and then set the display start.
				if ($startDate != '') {
					//Set display start date as first spot date.
					$day_display_start = date("Y-m-d", strtotime($startDate));
				} else {
					//Set display start date as today.
					$day_display_start = date("Y-m-d");
				}
			}
		}
		// Decide on the start date.
		if (globalize("day_start") != '') {
			$day_start = globalize("day_start");
		} elseif (isset($day_display_start) && $day_display_start != '') {
			$day_start = $day_display_start;
		} else {
			$day_start = date("Y-m-d");
		}

		// Decide on the amount of days to view.
		if (globalize("day_start") != '') {
			$day_start = globalize("day_start");
		} elseif (isset($day_display_start) && $day_display_start != '') {
			$day_start = $day_display_start;
		} else {
			$day_start = date("Y-m-d");
		}

		if ($action == 'reschedule') {
			$num_of_days = globalize('view_days',14);
		} else {
			$num_of_days = globalize('num_of_days',14);
		}
        $num_of_hours = globalize('num_of_hours',24);
		// TODO: the following variable needs to be a Module Parameter
        $display_start_time = globalize("hour_start", '06:00:00');
        list($display_start_time_hours,$display_start_time_minutes,$display_start_time_seconds) = preg_split('/:/',$display_start_time);

        $display_start_day = new DateTime($day_start);

        $display_end_day = clone $display_start_day; $display_end_day->modify("+".$num_of_days." day");

        $display_start_day_str = $display_start_day->format("Y-m-d");
        $display_end_day_str = $display_end_day->format("Y-m-d");

        $alltimes = range(0,$num_of_hours-1);
        array_walk($alltimes,create_function('&$str','$str = sprintf("%02d:00:00",$str);'));
        $alltimes = self::rotate($alltimes,$display_start_time);
        $alltimes[] = $alltimes[0]; //Append the last one so we can detect end of the final slot.
        //print_r($alltimes);

        $date_counter = clone $display_start_day;

		// Remove residual action state from a previous reschedule action.
		if ($action == 'reschedule') {
			$action = '';
		}

        $form = module::form_dom($doc);
        $form->appendChild($hidden = dom::createInputBox($doc,'item',globalize('item',get_class($this)),'hidden'));
        $form->appendChild($grid = $doc->createElement('div'));

        $h1 = $doc->createElement('h1');
        $h1->appendChild($doc->createTextNode('Traffic Display Grid'));
        $grid->appendChild($h1);

        $grid->appendChild($divSelect = $doc->createElement('div'));
		$divSelect->appendChild($spanPriority = $doc->createElement('span'));
		$spanPriority->setAttribute('class', 'link_find_small');
		$spanPriority->setAttribute('title', 'Focus');
		$spanPriority->appendChild($doc->createTextNode('Focus: '));

        $modeselect = dom::createDropdown($doc,'mode',array('All'=>'All','Client'=>'Client',
                                                        'Contract'=>'Contract',
                                                        'Campaign'=>'Campaign',
                                                        'Audio'=>'CampaignAudio'),$mode);
        $modeselect->setAttribute('onChange','this.form.submit()');
        $divSelect->appendChild($modeselect);

		// Retrieve all the spots-of-interest, if narrowing the scope-of-interest.
        switch($mode) {
            case 'Client':
                $clientselect = Client::display_select($doc,'',$clientID);
                $clientselect->setAttribute('onChange','this.form.submit()');
                $divSelect->appendChild($clientselect);

                if ($clientID != '') {
                    $query = <<<EOQ
                        SELECT S.{$this->store->field_spot_dateTime} AS dateTime
                        FROM ({$this->store->table_traffic_spot} S,
							{$this->store->table_traffic_campaignaudio} A
						)
                        WHERE S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
                        AND A.{$this->store->field_campaignaudio_clientID} = $clientID
EOQ;
                    $highlightoverlay = sysdb::query2vector($query,'dateTime');
                }
                break;
            case 'Contract':
                $contractselect = Contract::display_select($doc,'',$contractID);
                $contractselect->setAttribute('onChange','this.form.submit()');
                $divSelect->appendChild($contractselect);

                if ($contractID != '') {
                    $query = <<<EOQ
                        SELECT S.{$this->store->field_spot_dateTime} AS dateTime
                        FROM ({$this->store->table_traffic_spot} S,
							{$this->store->table_traffic_campaignaudio} A
						)
                        WHERE S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
                        AND A.{$this->store->field_campaignaudio_contractID} = $contractID
EOQ;
                    $highlightoverlay = sysdb::query2vector($query,'dateTime');
                }
                break;
            case 'Campaign':
                $campaignselect = Campaign::display_select($doc,'',$campaignID);
                $campaignselect->setAttribute('onChange','this.form.submit()');
                $divSelect->appendChild($campaignselect);

                if ($campaignID != '') {
                    $query = <<<EOQ
                        SELECT S.{$this->store->field_spot_dateTime} AS dateTime
                        FROM ({$this->store->table_traffic_spot} S,
							{$this->store->table_traffic_campaignaudio} A
						)
                        WHERE S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
                        AND A.{$this->store->field_campaignaudio_campaignID} = $campaignID
EOQ;
                    $highlightoverlay = sysdb::query2vector($query,'dateTime');
                }
                break;
            case 'CampaignAudio':
                if (globalize('action') == 'Add Spot' && $campaignAudioID != '') {
                    $spot = globalize('spot');
					// Adds a new single spot, adding it as the lowest priority.
                    $query = <<<EOQ
                        INSERT INTO {$this->store->table_traffic_spot} (
							{$this->store->field_spot_mediaID},
							{$this->store->field_spot_dateTime},
							{$this->store->field_spot_priority}
						)
                        SELECT {$this->store->field_spot_mediaID} AS mediaID,
							'$spot' AS dateTime,
							(SELECT COALESCE(MAX({$this->store->field_spot_priority}),0) + 1
							FROM {$this->store->table_traffic_spot}
							WHERE {$this->store->field_spot_dateTime} = '$spot') AS priority
                        FROM {$this->store->table_traffic_campaignaudio}
                        WHERE campaignAudioID = $campaignAudioID
EOQ;
                    sysdb::query($query);
                }

                $audioselect = CampaignAudio::display_select($doc,'',$campaignAudioID);
                $audioselect->setAttribute('onChange','this.form.submit()');
                $divSelect->appendChild($audioselect);

                if ($campaignAudioID != '') {
                    $query = <<<EOQ
                        SELECT S.{$this->store->field_spot_dateTime} AS dateTime
                        FROM ({$this->store->table_traffic_spot} S,
							{$this->store->table_traffic_campaignaudio} A
						)
                        WHERE S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
                        AND A.{$this->store->field_campaignaudio_campaignAudioID} = $campaignAudioID
EOQ;
                    $highlightoverlay = sysdb::query2vector($query,'dateTime');
                }
                break;
        }

        $grid->appendChild($divHeader = $doc->createElement('div'));
        $divHeader->setAttribute('id', 'traffic_header_container');
        $divHeader->appendChild($tblnav = $doc->createElement('table'));
        $tblnav->setAttribute('id', 'navtble');
        $tblnav->setAttribute('class', 'traffic_table');

        $tblnav->appendChild($tr = $doc->createElement('tr'));
        $tr->appendChild($left = $doc->createElement('th'));

		// Change the date navigation values when in daily view.
        if ($num_of_days == 1) {
			$short_interval = 'Day';
			$long_interval = 'Week';
		} elseif ($num_of_days == 7) {
			$short_interval = 'Week';
			$long_interval = 'Month';
		} elseif ($num_of_days == 14) {
			$short_interval = 'Fortnight';
			$long_interval = 'Month';
		} elseif ($num_of_days == 31) {
			$short_interval = 'Month';
			$long_interval = 'Year';
		} else {
			$short_interval = 'Week';
			$long_interval = 'Month';
		}

        $display_minus_month = clone $display_start_day;
        $display_minus_month->modify('-1 '.$long_interval);
        $left->appendChild(module::link_to_script_dom_unappended($doc,'Previous '.$long_interval,'',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>$num_of_days,
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_minus_month->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'Previous '.$long_interval,'link_prev2_small'));


        $display_minus_week = clone $display_start_day;
        $display_minus_week->modify('-1 '.$short_interval);
        $left->appendChild(module::link_to_script_dom_unappended($doc,'Previous '.$short_interval,'',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>$num_of_days,
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_minus_week->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'Previous '.$short_interval,'link_prev_small'));

		// these are the calendar view icons for traffic. They are currently inactive
        $tr->appendChild($middle = $doc->createElement('th'));

        $middle->appendChild(module::link_to_script_dom_unappended($doc,'View by Day','',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>'1',
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_start_day->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'View by Day','link_day_small'));

        $middle->appendChild(module::link_to_script_dom_unappended($doc,'View by Week','',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>'7',
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_start_day->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'View by Week','link_week_small'));

        $middle->appendChild(module::link_to_script_dom_unappended($doc,'View by Fortnight','',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>'14',
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_start_day->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'View by Fortnight','link_range_small'));

        $middle->appendChild(module::link_to_script_dom_unappended($doc,'View by Month','',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>'31',
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_start_day->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'View by Month','link_month_small'));

// range doesn't work yet
//        $middle->appendChild(module::link_to_script_dom_unappended($doc,'View by Date Range','','','View by Date Range','link_range_small'));

        $tr->appendChild($right = $doc->createElement('th'));

        $display_plus_week = clone $display_start_day;
        $display_plus_week->modify('+1 '.$short_interval);
        $right->appendChild(module::link_to_script_dom_unappended($doc,'Next '.$short_interval,'',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>$num_of_days,
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_plus_week->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'Next '.$short_interval,'link_next_small'));

        $display_plus_month = clone $display_start_day;
        $display_plus_month->modify('+1 '.$long_interval);
        $right->appendChild(module::link_to_script_dom_unappended($doc,'Next '.$long_interval,'',
                        array('item'=>globalize('item',get_class($this)),
                              'num_of_days'=>$num_of_days,
                              'num_of_hours'=>$num_of_hours,
                              'hour_start'=>$display_start_time,
                              'day_start'=>$display_plus_month->format('Y-m-d'),
                              'action'=>$action,
                              'clientID'=>$clientID,
                              'contractID'=>$contractID,
                              'campaignID'=>$campaignID,
                              'campaignAudioID'=>$campaignAudioID,
                              'mode'=>$mode
                              ),'Next '.$long_interval,'link_next2_small'));

		// Draw a legend/key for describing the colours used.
		$divHeader->appendChild($tblkey = $doc->createElement('table'));
        $tblkey->setAttribute('id', 'keytble');
        $tblkey->setAttribute('class', 'traffic_table');
        $tblkey->appendChild($tr = $doc->createElement('tr'));

		$styleshade = 10;

		$shadetype = '';
        $tr->appendChild($label = $doc->createElement('td'));
//		$label->setAttribute('class', "traffic_key");
		$label->appendChild($div = $doc->createElement('div'));
		$div->appendChild($doc->createTextNode('KEY: '));

		$varpop = 'normal';
        $tr->appendChild($normal = $doc->createElement('td'));
		$normal->setAttribute('class', "traffic_key");
		$normal->appendChild($div = $doc->createElement('div'));
		$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$div->setAttribute('onmouseover', 'popupkey(this,"'.$varpop.'");');
		$div->setAttribute('onmouseout', 'popoutkey("'.$varpop.'");');
		$div->appendChild($doc->createTextNode(' '));

		// Start normal popup box.
		$popupdiv = $doc->createElement('div');
		$popupdiv->setAttribute('class', 'popup_small');
		$popupdiv->setAttribute('id', 'popkey["'.$varpop.'"]');
		$popupdiv->setAttribute('visibility', 'hidden');
		$popupdiv->appendChild($popuptable = $doc->createElement('table'));
        $popuptable->setAttribute('class', 'traffic_popkey');
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		// TODO: Get popups closing using button (and change onmouseover to onclick). Close icon disabled until then.
/*		$tdP->appendChild($span = $doc->createElement('span'));
		$span->setAttribute('class', 'link_close_small');
		$span->setAttribute('style', 'float: right;');
		$span->setAttribute('onclick', 'popoutkey("'.$varpop.'");');
		$span->appendChild($doc->createTextNode(' '));
*/		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($thP = $doc->createElement('th'));
		$thP->appendChild($doc->createTextNode('NORMAL'));
		$thP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Everything is within specified parameters.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Normal cells will be weighted according to the remaining schedule time in that hour, with progressively darker colours denoting heavier scheduling.'));
		$div->appendChild($popupdiv);
		// End normal popup box.

		$varpop = 'warn';
		$shadetype = '_warn';
        $tr->appendChild($warning = $doc->createElement('td'));
		$warning->setAttribute('class', "traffic_key");
		$warning->appendChild($div = $doc->createElement('div'));
		$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$div->setAttribute('onmouseover', 'popupkey(this,"'.$varpop.'");');
		$div->setAttribute('onmouseout', 'popoutkey("'.$varpop.'");');
		// $div->setAttribute('onclick', 'popupkey(this,"'.$varpop.'");');
		$div->appendChild($doc->createTextNode(' '));

		// Start warning popup box.
		$popupdiv = $doc->createElement('div');
		$popupdiv->setAttribute('class', 'popup_small');
		$popupdiv->setAttribute('id', 'popkey["'.$varpop.'"]');
		$popupdiv->setAttribute('visibility', 'hidden');
		$popupdiv->appendChild($popuptable = $doc->createElement('table'));
        $popuptable->setAttribute('class', 'traffic_popkey');
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		// TODO: Get popups closing using button (and change onmouseover to onclick). Close icon disabled until then.
/*		$tdP->appendChild($span = $doc->createElement('span'));
		$span->setAttribute('class', 'link_close_small');
		$span->setAttribute('style', 'float: right;');
		$span->setAttribute('onclick', 'popoutkey("'.$varpop.'");');
		$span->appendChild($doc->createTextNode(' '));
*/		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($thP = $doc->createElement('th'));
		$thP->appendChild($doc->createTextNode('WARNING'));
		$thP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('A warning notifies that a spot is violating pre-defined predicates, but they will still play on air.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Warning cells will be weighted according to the remaining schedule time in that hour, with progressively darker colours denoting heavier scheduling.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Reasons for warnings include:'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Contract Status is not Approved or Paid or Invoiced.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Production Status is not Approved.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Spot is scheduled before production deadline. '));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Spot is scheduled before allocated Audio start date. '));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Spot is scheduled after allocated Audio end date. '));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Spot is scheduled before allocated Campaign start date. '));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Spot is scheduled after allocated Campaign end date.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Hover over spots to view these notifications.'));
		$div->appendChild($popupdiv);
		// End warning popup box.

		$varpop = 'error';
		$shadetype = '_error';
        $tr->appendChild($error = $doc->createElement('td'));
		$error->setAttribute('class', "traffic_key");
		$error->appendChild($div = $doc->createElement('div'));
		$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$div->setAttribute('onmouseover', 'popupkey(this,"'.$varpop.'");');
		$div->setAttribute('onmouseout', 'popoutkey("'.$varpop.'");');
		// $div->setAttribute('onclick', 'popupkey(this,"'.$varpop.'");');
		$div->appendChild($doc->createTextNode(' '));

		// $popupdiv = $doc->createElement('div');
		// $popupdiv->setAttribute('class', 'popup_small');
		// $popupdiv->setAttribute('id', 'popkey["'.$varpop.'"]');
		// $popupdiv->setAttribute('visibility', 'hidden');
		// $popupdiv->appendChild($doc->createTextNode('An error denotes that the audio cannot be played for some reason. This means that either audio duration is 0 seconds, or production deadline has passed with no audio uploaded.'));

		// $popupdiv->appendChild($span = $doc->createElement('span'));
		// $span->setAttribute('class', 'link_close_small');
		// $span->setAttribute('style', 'float: right;');
		// $span->setAttribute('onclick', 'popoutkey("'.$varpop.'");');
		// $span->appendChild($doc->createTextNode(' '));
		// $div->appendChild($popupdiv);

		// Start error popup box.
		$popupdiv = $doc->createElement('div');
		$popupdiv->setAttribute('class', 'popup_small');
		$popupdiv->setAttribute('id', 'popkey["'.$varpop.'"]');
		$popupdiv->setAttribute('visibility', 'hidden');
		$popupdiv->appendChild($popuptable = $doc->createElement('table'));
        $popuptable->setAttribute('class', 'traffic_popkey');
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		// TODO: Get popups closing using button (and change onmouseover to onclick). Close icon disabled until then.
/*		$tdP->appendChild($span = $doc->createElement('span'));
		$span->setAttribute('class', 'link_close_small');
		$span->setAttribute('style', 'float: right;');
		$span->setAttribute('onclick', 'popoutkey("'.$varpop.'");');
		$span->appendChild($doc->createTextNode(' '));
*/		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($thP = $doc->createElement('th'));
		$thP->appendChild($doc->createTextNode('ERROR'));
		$thP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('An error denotes that the audio cannot be played for some reason.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Error cells will be weighted according to the remaining schedule time in that hour, with progressively darker colours denoting heavier scheduling.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Errors over-ride warnings.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('The types of error messages are:'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Audio duration is 0 seconds.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Production deadline has passed with no audio uploaded.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Air date is in less than three days and Production Status is not Approved.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$tdP->appendChild($doc->createTextNode('Air date is in less than three days and Contract Status is not Approved or Paid or Invoiced.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('Hover over spots to view these notifications.'));
		$div->appendChild($popupdiv);
		// End error popup box.

		$varpop = 'full';
		$shadetype = '_full';
        $tr->appendChild($full = $doc->createElement('td'));
		$full->setAttribute('class', "traffic_key");
		$full->appendChild($div = $doc->createElement('div'));
		$div->setAttribute('class', "traffic_shade20$shadetype");
		$div->setAttribute('onmouseover', 'popupkey(this,"'.$varpop.'");');
		$div->setAttribute('onmouseout', 'popoutkey("'.$varpop.'");');
		// $div->setAttribute('onclick', 'popupkey(this,"'.$varpop.'");');
		$div->appendChild($doc->createTextNode(' '));

		// Start full popup box.
		$popupdiv = $doc->createElement('div');
		$popupdiv->setAttribute('class', 'popup_small');
		$popupdiv->setAttribute('id', 'popkey["'.$varpop.'"]');
		$popupdiv->setAttribute('visibility', 'hidden');
		$popupdiv->appendChild($popuptable = $doc->createElement('table'));
        $popuptable->setAttribute('class', 'traffic_popkey');
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		// TODO: Get popups closing using button (and change onmouseover to onclick). Close icon disabled until then.
/*		$tdP->appendChild($span = $doc->createElement('span'));
		$span->setAttribute('class', 'link_close_small');
		$span->setAttribute('style', 'float: right;');
		$span->setAttribute('onclick', 'popoutkey("'.$varpop.'");');
		$span->appendChild($doc->createTextNode(' '));
*/		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($thP = $doc->createElement('th'));
		$thP->appendChild($doc->createTextNode('TIME EXCEEDED'));
		$thP->setAttribute('class', "traffic_shade20$shadetype");
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('A time exceeded error denotes that the time slot is full, and has been overbooked.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('This may cause a breach in broadcasting terms of service and should be addressed immediately.'));
		$div->appendChild($popupdiv);
		// End full popup box.

		$varpop = 'grey';
		$shadetype = '_grey';
        $tr->appendChild($grey = $doc->createElement('td'));
		$grey->setAttribute('class', "traffic_key");
		$grey->appendChild($div = $doc->createElement('div'));
		$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$div->setAttribute('onmouseover', 'popupkey(this,"'.$varpop.'");');
		$div->setAttribute('onmouseout', 'popoutkey("'.$varpop.'");');
		// $div->setAttribute('onclick', 'popupkey(this,"'.$varpop.'");');
		$div->appendChild($doc->createTextNode(' '));

		// Start grey popup box.
		$popupdiv = $doc->createElement('div');
		$popupdiv->setAttribute('class', 'popup_small');
		$popupdiv->setAttribute('id', 'popkey["'.$varpop.'"]');
		$popupdiv->setAttribute('visibility', 'hidden');
		$popupdiv->appendChild($popuptable = $doc->createElement('table'));
        $popuptable->setAttribute('class', 'traffic_popkey');
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		// TODO: Get popups closing using button (and change onmouseover to onclick). Close icon disabled until then.
/*		$tdP->appendChild($span = $doc->createElement('span'));
		$span->setAttribute('class', 'link_close_small');
		$span->setAttribute('style', 'float: right;');
		$span->setAttribute('onclick', 'popoutkey("'.$varpop.'");');
		$span->appendChild($doc->createTextNode(' '));
*/		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($thP = $doc->createElement('th'));
		$thP->appendChild($doc->createTextNode('OUT OF FOCUS'));
		$thP->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('The grey boxes indicate that the object of interest is not scheduled in that hour. '));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('For instance, if only the traffic distribution for one campaign audio is being viewed, the hours without that audio will be greyed.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('When viewing the entire traffic grid, no cells will be greyed because the focus is on the entire traffic schedule, not an individual item.'));
		$popuptable->appendChild($trP = $doc->createElement('tr'));
		$trP->appendChild($tdP = $doc->createElement('td'));
		$tdP->appendChild($doc->createTextNode('These out of focus cells will be weighted according to the remaining schedule time in that hour, with progressively darker shades denoting heavier scheduling.'));
		$div->appendChild($popupdiv);
		// End grey popup box.

		// Fetch start and end date values.
		$date_start = $date_counter->format("Y-m-d");
		$date_end = date("Y-m-d", strtotime("+".$num_of_days." day", strtotime($date_start)));
		$hour_start = date("H:i:s", strtotime($display_start_time));
		$hour_end = date("H:i:s", strtotime("-1 hour", strtotime($display_start_time)));

		// Fetch all spot information.
		$query = <<<EOQ
			SELECT S.{$this->store->field_spot_dateTime} AS dateTime,
				(SELECT SUBSTRING(S.{$this->store->field_spot_dateTime} FROM 12)) AS time,
				A.{$this->store->field_campaignaudio_campaignAudioID} AS campaignAudioID,
				A.{$this->store->field_campaignaudio_duration} AS duration,
				A.{$this->store->field_campaignaudio_name} AS campaignAudio,
				A.{$this->store->field_campaignaudio_productionStatus} AS productionStatus,
				A.{$this->store->field_campaignaudio_filename} AS filename,
				A.{$this->store->field_campaignaudio_deadlineDate} AS productionDeadline,
				A.{$this->store->field_campaignaudio_startDate} AS audioStartDate,
				A.{$this->store->field_campaignaudio_endDate} AS audioEndDate,
				C.{$this->store->field_campaign_name} AS campaign,
				C.{$this->store->field_campaign_campaignID} AS campaignID,
				C.{$this->store->field_campaign_startDate} AS campaignStartDate,
				C.{$this->store->field_campaign_endDate} AS campaignEndDate,
				O.{$this->store->field_contract_name} AS contract,
				O.{$this->store->field_contract_contractID} AS contractID,
				O.{$this->store->field_contract_contractStatus} AS contractStatus,
				L.{$this->store->field_client_name} AS client,
				L.{$this->store->field_client_clientID} AS clientID,
				S.{$this->store->field_spot_priority} AS priority,
				S.{$this->store->field_spot_spotID} AS spotID
			FROM ({$this->store->table_traffic_spot} S,
				{$this->store->table_traffic_campaignaudio} A
			)
			INNER JOIN {$this->store->table_traffic_campaign} C
				ON A.{$this->store->field_campaignaudio_campaignID} = C.{$this->store->field_campaign_campaignID}
			INNER JOIN {$this->store->table_traffic_contract} O
				ON A.{$this->store->field_campaignaudio_contractID} = O.{$this->store->field_contract_contractID}
			INNER JOIN {$this->store->table_traffic_client} L
				ON A.{$this->store->field_campaignaudio_clientID} = L.{$this->store->field_client_clientID}
			WHERE S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
			AND S.{$this->store->field_spot_dateTime} >= "$date_start $hour_start"
			AND S.{$this->store->field_spot_dateTime} < "$date_end $hour_end"
			ORDER BY dateTime, priority, spotID
EOQ;
		$result = sysdb::query($query);

		$schedule = array();
		while ($row = sysdb::fetch_assoc($result)) {
			// Round spot times down to the hour, using an arbitrary date.
			$key_local_hour_time = strtotime(date("Y-m-d H:i:s", strtotime(date("Y-m-d H", strtotime("2001-01-01 ".$row['time'])).":00:00")));
			// echo date("Y-m-d H:i:s", $key_local_hour_time)."<br/>";

			// As there may be multiple slots within a given temporal hour, group spots by the hour in an associative array for later processing.
			$key_local_date = strtotime($row['dateTime']);
			$schedule[$key_local_hour_time][$key_local_date][] = $row;
		}

		// Free memory.
		sysdb::free($result);

		// Decide on grid versus daily view.
        if ($num_of_days != 1) {
			// Proceed to display traffic in x/y grid.
			$tblmain = $doc->createElement('table');
			$tblmain->setAttribute('id', 'xytble');
			$tblmain->setAttribute('class', 'traffic_table');

			$linehead = $doc->createElement('tr');
			$linehead->setAttribute('id', 'traffic_head_row');
			$linehead->setAttribute('class', 'traffic_head_row');

			$blank = $doc->createElement('td');
			$linehead->appendChild($blank);

			for($j=0;$j<$num_of_days;$j++) {
				$linehead->appendChild($boxhead[$j] = $doc->createElement('td'));
				$boxhead[$j]->setAttribute('id', "traffic_head_box[{$j}]");
				if ($num_of_days == 31) {
					if ($date_counter->format("N") == 6 || $date_counter->format("N") == 7) {
						$boxhead[$j]->setAttribute('class', 'traffic_head_box_month_we');
					} else {
						$boxhead[$j]->setAttribute('class', 'traffic_head_box_month');
					}
				} else {
					if ($date_counter->format("N") == 6 || $date_counter->format("N") == 7) {
						$boxhead[$j]->setAttribute('class', 'traffic_head_box_we');
					} else {
						$boxhead[$j]->setAttribute('class', 'traffic_head_box');
					}
				}
				$boxhead[$j]->setAttribute('title', $date_counter->format("l jS \of F, Y"));
				$boxhead[$j]->appendChild(module::link_to_script_dom_unappended($doc,'View '.$date_counter->format("l jS \of F, Y").' by Day','',
								array('item'=>globalize('item',get_class($this)),
									  'num_of_days'=>'1',
									  'num_of_hours'=>$num_of_hours,
									  'hour_start'=>$display_start_time,
									  'day_start'=>$date_counter->format('Y-m-d'),
									  'action'=>$action,
									  'clientID'=>$clientID,
									  'contractID'=>$contractID,
									  'campaignID'=>$campaignID,
									  'campaignAudioID'=>$campaignAudioID,
									  'mode'=>$mode
									  ),'View '.$date_counter->format("l jS \of F, Y").' by Day',''));
				if ($num_of_days == 31) {
					$boxhead[$j]->appendChild($doc->createTextNode(substr($date_counter->format("D"), 0, 1)));
					$boxhead[$j]->appendChild($doc->createElement('br'));
					$boxhead[$j]->appendChild($doc->createTextNode($date_counter->format("j")));
					$boxhead[$j]->appendChild($doc->createElement('br'));
					$boxhead[$j]->appendChild($doc->createTextNode(substr($date_counter->format("M"), 0, 1)));
				} else {
					$boxhead[$j]->appendChild($doc->createTextNode($date_counter->format("D")));
					$boxhead[$j]->appendChild($doc->createElement('br'));
					$boxhead[$j]->appendChild($doc->createTextNode($date_counter->format("d/m")));
				}
				$date_counter->modify("+1 day");
			}

			$tblmain->appendChild($linehead);
			$date_counter->modify("+$display_start_time_hours hours $display_start_time_minutes minutes $display_start_time_seconds seconds");

			// Cycle through rows (slot hours).
			for ($i = 0; $i < sizeof($alltimes)-1; $i++) {
				$row_start = $alltimes[$i];
				$row_next = $alltimes[$i+1];

				$line[$i] = $doc->createElement('tr');
				$line[$i]->setAttribute('id', "traffic_row[{$i}]");
				$line[$i]->setAttribute('class', 'traffic_row');

				$time = $doc->createElement('td');
				$time->setAttribute('id', "traffic_row_lead[$i]");
				$time->setAttribute('class', "traffic_head_box");
				$time->appendChild($doc->createTextNode(date("G:i", strtotime($row_start))));

				$line[$i]->appendChild($time);

				$date_counter = clone $display_start_day;

				if ($row_start < $display_start_time) {
					$date_counter->modify("+1 day");
				}

				// Cycle through columns (days).
				for($j=0;$j<$num_of_days;$j++) {
					$cell_day = $date_counter->format("Y-m-d");
					$cell_dow = $date_counter->format("l");

					if ($row_next < $row_start) {
						$date_counter->modify("+1 day");
					}
					$cell_next_day = $date_counter->format("Y-m-d");

					// Check to see our overlap with other slots.
					$query = <<<EOQ
						SELECT {$this->store->field_slot_time} AS time
						FROM {$this->store->table_traffic_slot}
						WHERE {$this->store->field_slot_startDate} <= '$cell_day'
						AND ({$this->store->field_slot_endDate} IS NULL
							OR {$this->store->field_slot_endDate} >= '$cell_next_day'
						)
						AND {$this->store->field_slot_dow} = "$cell_dow"
						AND {$this->store->field_slot_time} >= "$row_start"
EOQ;
					if ($row_next > $row_start) {
						$query .= " AND {$this->store->field_slot_time} < '$row_next' ";
					}
					$query .= <<<EOQ
						ORDER BY time
						LIMIT 0, 2
EOQ;

					//This query tells us two things:
					//1) Does a slot exist at this time?
					$result = sysdb::query_assoc($query,false);
					if (sizeof($result) <= 0) {
						$slot_exists = false;
					} else  {
						$slot_exists = true;
					}

					if ($slot_exists) {
						$rowspan = 1;

						//if ($alltimes[$i+$rowspan] != $next_known_slot_in_column) echo 'Error! Rowspan calculation failed!';

						// Search values.
						$key_local_search_time = strtotime(date("Y-m-d H:i:s", strtotime(date("Y-m-d H", strtotime("2001-01-01 ".$row_start)).":00:00")));
						$key_global_search_date = strtotime($cell_day." ".$row_start);

						$spots = array();
						if(array_key_exists($key_local_search_time, $schedule)) {
							if(array_key_exists($key_global_search_date, $schedule[$key_local_search_time])) {
								if (sizeof($schedule[$key_local_search_time][$key_global_search_date]) > 0) {
									// Do something with results.
									$spots = $schedule[$key_local_search_time][$key_global_search_date];
								}
								// Remove record from results to free up memory.
								unset($schedule[$key_local_search_time][$key_global_search_date]);
							}
						}

						$warn = array();
						$error = array();
						$timeoccupied = 0;

						// Check each spot for errors.
						foreach ($spots as $spotline) {
							$timeoccupied += $spotline['duration'];
							$warn[$spotline['campaignAudioID']] = '';
							$error[$spotline['campaignAudioID']] = '';

							if ($spotline['filename'] != ''
								&& $spotline['productionStatus'] == 'Approved'
								&& ($spotline['contractStatus'] == 'Approved'
									|| $spotline['contractStatus'] == 'Invoiced'
									|| $spotline['contractStatus'] == 'Paid')
							) {
								// Spot is approved with uploaded media and is ready to play out.
							} else {

								// Roughly in severity then procedure order.

								// File: NO;
								if ($spotline['filename'] == '') {
									$error_text = '';
									if (strtotime("now") >= strtotime($spotline['productionDeadline'])) {
										$error_text .= 'Production deadline has passed with no audio uploaded';
									} else {
										$error_text .= 'No audio is uploaded';
									}
									if ($spotline['contractStatus'] == 'Proposed'
										|| $spotline['contractStatus'] == 'Cancelled'
									) {
										$error_text .= ' and Contract Status is not Approved or Paid or Invoiced';
									}
									if ($spotline['productionStatus'] != 'Approved') {
										$error_text .= ' and Production Status is not Approved';
									}

									$error[$spotline['campaignAudioID']] = $error_text;
									continue;
								}

								// File: YES; Contract: NO; Production: NO;
								if ($spotline['filename'] != ''
									&& $spotline['productionStatus'] != 'Approved'
									&& ($spotline['contractStatus'] == 'Proposed'
										|| $spotline['contractStatus'] == 'Cancelled')
									) {
									$error[$spotline['campaignAudioID']] = 'Audio is uploaded but Contract Status and Production Status are not Approved';
									continue;
								}

								// File: YES; Contract: NO; Production: YES;
								if ($spotline['filename'] != ''
									&& $spotline['productionStatus'] == 'Approved'
									&& ($spotline['contractStatus'] == 'Proposed'
										|| $spotline['contractStatus'] == 'Cancelled')
									) {
									$error[$spotline['campaignAudioID']] = 'Audio is uploaded but Contract Status is not Approved or Paid or Invoiced';
									continue;
								}

								// File: YES; Contract: YES; Production: NO;
								if ($spotline['filename'] != ''
									&& $spotline['productionStatus'] != 'Approved'
									&& ($spotline['contractStatus'] == 'Approved'
										|| $spotline['contractStatus'] == 'Invoiced'
										|| $spotline['contractStatus'] == 'Paid')
									) {
									$error[$spotline['campaignAudioID']] = 'Audio is uploaded but Production Status is not Approved';
									continue;
								}

								if (strtotime("now") >= strtotime("-3 day",strtotime($cell_day))
									&& $spotline['productionStatus'] != 'Approved') {
									$error[$spotline['campaignAudioID']] = 'Air date is in less than three days and Production Status is not Approved';
									continue;
								}

								if (strtotime("now") >= strtotime("-3 day",strtotime($cell_day))
									&& !in_array($spotline['contractStatus'],array('Approved','Paid','Invoiced'))) {
									$error[$spotline['campaignAudioID']] = 'Air date is in less than three days and Contract Status is not Approved or Paid or Invoiced';
									continue;
								}

								if ($spotline['duration'] == 0) {
									$error[$spotline['campaignAudioID']] = 'Audio Duration is 0!';
									continue;
								}

								if (strtotime($cell_day) < strtotime($spotline['productionDeadline'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled before production deadline';
									continue;
								}

								if (!in_array($spotline['contractStatus'],array('Approved','Paid','Invoiced'))) {
									$warn[$spotline['campaignAudioID']] = 'Contract Status is not Approved or Paid or Invoiced';
									continue;
								}

								if ($spotline['productionStatus'] != 'Approved') {
									$warn[$spotline['campaignAudioID']] = 'Production Status is not Approved';
									continue;
								}

								if (strtotime($cell_day) < strtotime($spotline['audioStartDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled before allocated Audio start date';
									continue;
								}

								if (strtotime($cell_day) > strtotime($spotline['audioEndDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled after allocated Audio end date';
									continue;
								}

								if (strtotime($cell_day) < strtotime($spotline['campaignStartDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled before allocated Campaign start date';
									continue;
								}

								if (strtotime($cell_day) > strtotime($spotline['campaignEndDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled after allocated Campaign end date';
									continue;
								}
							}
						}

						$box[$i][$j] = $doc->createElement('td');
						$box[$i][$j]->setAttribute('id', "traffic_box[{$i}][{$j}]");
						$box[$i][$j]->setAttribute('class', 'traffic_box');
						if ($rowspan != 1) $box[$i][$j]->setAttribute('rowspan', $rowspan);

						$styleshades = 20;
						$timeremaining = $maxtime-$timeoccupied;

						if ($timeremaining < 0) {
							$error[-1] = 'More than '.$maxtime.' s allocated to the hour.';
						}

						$div = $doc->createElement('div');
						$div->setAttribute('onclick', 'popupbox(this,'.$i.','.$j.');');
						//$div->setAttribute('onmouseout', 'popoutbox(this);');

						if (20-ceil(( ($timeremaining / $maxtime)*100)/5) > 20) $styleshade = 20; else $styleshade = 20-ceil(( ($timeremaining / $maxtime)*100)/5);
						$shadetype = '';
						if ($timeremaining < 0) { $styleshade = 20; $shadetype = '_full'; }
						else if (sizeof(array_filter($error)) > 0) $shadetype = '_error';
						else if (sizeof(array_filter($warn)) > 0) $shadetype = '_warn';
						if (isset($highlightoverlay) && !in_array($cell_day." ".$row_start,$highlightoverlay))
							$shadetype = '_grey';
						$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");

						if ($num_of_days == 31) {
							/** @todo Make this blank without requiring the dot to keep the div filled. */
							$div->appendChild($doc->createTextNode('.'));
						} else {
							$div->appendChild($doc->createTextNode($timeremaining.'s'));
						}
						//$div->appendChild($doc->createTextNode($next_known_slot_in_column));
						$box[$i][$j]->appendChild($div);

						$popupdiv = $doc->createElement('div');
						$popupdiv->setAttribute('class', 'popup_small');
						$popupdiv->setAttribute('id', 'popup['.$i.']['.$j.']');
						$popupdiv->setAttribute('visibility', 'hidden');
						$popupdiv->appendChild($popuptable = $doc->createElement('table'));
						$popuptable->appendChild($tr = $doc->createElement('tr'));
						$tr->appendChild($td = $doc->createElement('td'));
						$td->appendChild($span = $doc->createElement('span'));
						$span->setAttribute('class', 'link_close_small');
						$span->setAttribute('style', 'float: right;');
						$span->setAttribute('onclick', 'popoutbox();');
						$span->appendChild($doc->createTextNode(' '));
						$td->appendChild($doc->createTextNode(' '));

						// Find the available slots for this hour.
						$query = <<<EOQ
							SELECT DISTINCT {$this->store->field_slot_time} AS time
							FROM {$this->store->table_traffic_slot}
							WHERE {$this->store->field_slot_startDate} <= '$cell_day'
							AND ({$this->store->field_slot_endDate} IS NULL
								OR {$this->store->field_slot_endDate} >= '$cell_next_day'
							)
							AND {$this->store->field_slot_dow} = '$cell_dow'
							AND {$this->store->field_slot_time} >= '$row_start'
EOQ;
						if ($row_next != '00:00:00') {
							$query .= " AND {$this->store->field_slot_time} < '$row_next'";
						}
						$query .= " ORDER BY time";
						$slots = sysdb::query2vector($query, 'time');

						if (sizeof($slots) <= 0) {
							$popuptable->appendChild($tr = $doc->createElement('tr'));
							$tr->appendChild($td = $doc->createElement('td'));
							$td->appendChild($doc->createElement('No slots in this hour.'));
						}

						$currentTimestamp = date("U");

						// Cycle each available slot.
						foreach ($slots as $slottime) {
							$popuptable->appendChild($tr = $doc->createElement('tr'));
							$tr->appendChild($td = $doc->createElement('td'));
							$td->appendChild($slottable = $doc->createElement('table'));

							$slottable->setAttribute('class','traffic_popup');
							$slottable->appendChild($tr = $doc->createElement('tr'));
							$tr->appendChild($th = $doc->createElement('th'));
							$th->setAttribute('class','title');

							// Human readable date formatting: Y-m-d => d/m/Y
							$slot_date_exploded = explode("-",$cell_day);
							krsort($slot_date_exploded);
							$print_date = implode("/",$slot_date_exploded);

							$th->appendChild($doc->createTextNode($slottime.' '.$print_date));
							$th->setAttribute('colspan','6');

							$slottable->appendChild($tr = $doc->createElement('tr'));
							foreach (array("Reorder","Duration","Client","Contract","Campaign","Audio") as $header) {
								$tr->appendChild($th = $doc->createElement('th'));
								$th->appendChild($doc->createTextNode($header));
							}

							if (sizeof($spots) <= 0) {
								$slottable->appendChild($tr = $doc->createElement('tr'));
								$tr->appendChild($td = $doc->createElement('td'));
								$td->appendChild($doc->createTextNode('No spots'));
								$td->setAttribute('colspan','6');
							}
							foreach ($spots as $spotline) {
								$slottable->appendChild($tr = $doc->createElement('tr'));
								foreach (array('Priority','Duration','Client','Contract','Campaign','CampaignAudio') as $field) {
									$tr->appendChild($td = $doc->createElement('td'));
									if ($error[$spotline['campaignAudioID']] != '') {
										$td->setAttribute('class',"error");
										$td->setAttribute('title',$error[$spotline['campaignAudioID']]);
									}
									else if ($warn[$spotline['campaignAudioID']] != '') {
										$td->setAttribute('class',"warn");
										$td->setAttribute('title',$warn[$spotline['campaignAudioID']]);
									}
									$idname = strtolower($field{0}).substr($field,1);
									if ($field != 'Duration' && $field != 'Priority') {
										$td->appendChild($a = module::link_to_script_dom_unappended($doc,'','',
														array('item'=>$field,
															  'action'=>'view',
															  'id'=>$spotline[$idname.'ID']),
															  '',''));
										$a->appendChild($doc->createTextNode(utf8_decode($spotline[$idname])));
									} elseif ($field == 'Priority') {
										$divPriority = $doc->createElement('div');
										$spanPriority = $doc->createElement('span');
										$spanPriority->setAttribute('class', 'link_up_small');
										$spanPriority->appendChild(module::link_to_script_dom($doc,'Prioritize Up','',
														array('item'=>globalize('item',get_class($this)),
															  'num_of_days'=>$num_of_days,
															  'num_of_hours'=>$num_of_hours,
															  'hour_start'=>$display_start_time,
															  'day_start'=>$display_start_day->format('Y-m-d'),
															  'onclick'=>'popupbox(this,'.$i.','.$j.');',
															  'action'=>'reorder',
															  'spotID'=>$spotline['spotID'],
															  'shift_value'=>'-1'),
															  'Prioritize Up',''));
										$divPriority->appendChild($spanPriority);

										// // Temporary printout of actual priority value.
										// $spanPriority = $doc->createElement('span');
										// $spanPriority->appendChild($doc->createTextNode($spotline[$idname]));
										// $divPriority->appendChild($spanPriority);

										$spanPriority = $doc->createElement('span');
										$spanPriority->setAttribute('class', 'link_down_small');
										$spanPriority->appendChild(module::link_to_script_dom($doc,'Prioritize Down','',
														array('item'=>globalize('item',get_class($this)),
															  'num_of_days'=>$num_of_days,
															  'num_of_hours'=>$num_of_hours,
															  'hour_start'=>$display_start_time,
															  'day_start'=>$display_start_day->format('Y-m-d'),
															  'onclick'=>'popupbox(this,'.$i.','.$j.');',
															  'action'=>'reorder',
															  'spotID'=>$spotline['spotID'],
															  'shift_value'=>'1'),
															  'Prioritize Down',''));
										$divPriority->appendChild($spanPriority);

										$spanSchedule = $doc->createElement('span');
										$spanSchedule->setAttribute('class', 'link_schedule_small');
										$spanSchedule->appendChild(module::link_to_script_dom($doc,'reschedule','',
														array('item'=>globalize('item',get_class($this)),
															  'view_days'=>$num_of_days,
															  'day_start'=>$display_start_day->format('Y-m-d'),
															  'action'=>'reschedule',
															  'id'=>$spotline['spotID']),
															  'Reschedule'));
										$divPriority->appendChild($spanSchedule);

										$td->appendChild($divPriority);
									} else {
										$td->appendChild($doc->createTextNode(utf8_decode($spotline[$idname])));
									}
								}

							}

							$slottable->appendChild($tr = $doc->createElement('tr'));
							$tr->appendChild($td = $doc->createElement('td'));
							$td->setAttribute('class',"blue");
//							$td->setAttribute('colspan','4');
							$td->appendChild($doc->createTextNode('Total:'));
							$tr->appendChild($td = $doc->createElement('td'));
							if ($timeremaining < 0) {
								$td->setAttribute('class',"error");
							} else {
								$td->setAttribute('class',"blue");
							}
							$td->appendChild($doc->createTextNode($timeoccupied));

							$slotTimestamp = strtotime($cell_day.' '.$slottime);

							if ($mode == "CampaignAudio" && $campaignAudioID != '' && $currentTimestamp < $slotTimestamp) {
								$popuptable->appendChild($tr = $doc->createElement('tr'));
								$tr->appendChild($td = $doc->createElement('td'));
								$td->appendChild($span = $doc->createElement('span'));
								$span->setAttribute('class','link_add_small');
								$span->appendChild(module::link_to_script_dom_unappended($doc,'Add Spot','',
												array('item'=>globalize('item',get_class($this)),
													  'num_of_days'=>$num_of_days,
													  'num_of_hours'=>$num_of_hours,
													  'hour_start'=>$display_start_time,
													  'day_start'=>$display_start_day->format('Y-m-d'),
													  'action'=>'Add Spot',
													  'campaignAudioID'=>$campaignAudioID,
													  'mode'=>$mode,
													  'spot'=>$cell_day.' '.$slottime
													 ),'Add Spot','link_add_small'));
								$td->setAttribute('colspan','5');
							}
						}

						$box[$i][$j]->appendChild($popupdiv);

						$line[$i]->appendChild($box[$i][$j]);
					}
					if ($row_next > $row_start) {
						$date_counter->modify("+1 day");
					}
				}
				$tblmain->appendChild($line[$i]);
			}
			$grid->appendChild($tblmain);
		} else {
			// Display expanded daily view
			// TODO: does this need to be moved out to a separate function?

			$export_day = $date_counter->format("Y-m-d");
			// Check for program component dependency.
			if (file_exists(ROOT_COMPONENTS.'programs/moduleconfig.php')) {
				// This HTML link is the temporary link to test HTML export by program
				$exportHTML = module::link_to_script_dom($doc,'Export by Programs','programlogs2html.php',array('dates'=>$export_day),true,true,'Export by Programs');
				$grid->appendChild($exportHTML);
			}

			$tblmain = $doc->createElement('table');
			$tblmain->setAttribute('id', 'dailytble');
			$tblmain->setAttribute('class', 'traffic_table');

			$linehead = $doc->createElement('tr');
			$linehead->setAttribute('id', 'traffic_head_row');
			$linehead->setAttribute('class', 'traffic_head_row');

			$blank = $doc->createElement('td');
			$linehead->appendChild($blank);

			for($j=0;$j<$num_of_days;$j++) {
				$boxhead[$j] = $doc->createElement('td');
				$boxhead[$j]->setAttribute('id', "traffic_head_box[{$j}]");
				$boxhead[$j]->setAttribute('class', 'traffic_head_box');
				$boxhead[$j]->setAttribute('title', $date_counter->format("l jS \of F, Y"));
				$boxhead[$j]->setAttribute('colspan', '2');
				$boxhead[$j]->appendChild($doc->createTextNode($date_counter->format("D")));
				$boxhead[$j]->appendChild($doc->createTextNode(' '));
//				$boxhead[$j]->appendChild($doc->createElement('br'));
				$boxhead[$j]->appendChild($doc->createTextNode($date_counter->format("d/m")));
				$linehead->appendChild($boxhead[$j]);
				$date_counter->modify("+1 day");
			}

			$tblmain->appendChild($linehead);
			$date_counter->modify("+".$display_start_time);

			for ($i = 0; $i < sizeof($alltimes)-1; $i++) {
				$row_start = $alltimes[$i];
				$row_next = $alltimes[$i+1];

				$line[$i] = $doc->createElement('tr');
				$line[$i]->setAttribute('id', "traffic_row[{$i}]");
				$line[$i]->setAttribute('class', 'traffic_row');

				$time = $doc->createElement('td');
				$time->setAttribute('id', "traffic_row_lead[$i]");
				$time->setAttribute('class', "traffic_head_box");
				$time->appendChild($doc->createTextNode(date("G:i",strtotime($row_start))));

				$line[$i]->appendChild($time);

				$date_counter = clone $display_start_day;

				if ($row_start < $display_start_time) {
					$date_counter->modify("+1 day");
				}

				for($j=0;$j<$num_of_days;$j++) {
					$cell_day = $date_counter->format("Y-m-d");
					$cell_dow = $date_counter->format("l");
					if ($row_next < $row_start) {
						$date_counter->modify("+1 day");
					}
					$cell_next_day = $date_counter->format("Y-m-d");

					//Check to see our overlap with other slots
					$query = <<<EOQ
						SELECT {$this->store->field_slot_time} AS time
						FROM {$this->store->table_traffic_slot}
						WHERE {$this->store->field_slot_startDate} <= '$cell_day'
						AND ({$this->store->field_slot_endDate} IS NULL OR {$this->store->field_slot_endDate} >= '$cell_next_day')
						AND {$this->store->field_slot_dow} = "$cell_dow"
						AND {$this->store->field_slot_time} >= "$row_start"

EOQ;
					if ($row_next > $row_start) {
						$query .= " AND {$this->store->field_slot_time} < '$row_next' ";
					}
					$query .= <<<EOQ
						ORDER BY time
						LIMIT 0,2
EOQ;

					//This query tells us two things:
					//1) Does a slot exist at this time?
					$result = sysdb::query_assoc($query, false);
					if (sizeof($result) <= 0) {
						$slot_exists = false;
					} else  {
						$slot_exists = true;
					}

					if ($slot_exists) {
						$rowspan = 1;

						//if ($alltimes[$i+$rowspan] != $next_known_slot_in_column) echo 'Error! Rowspan calculation failed!';

						$query = <<<EOQ
							SELECT A.{$this->store->field_campaignaudio_campaignAudioID} AS campaignAudioID,
									A.{$this->store->field_campaignaudio_duration} AS duration,
									A.{$this->store->field_campaignaudio_name} AS campaignAudio,
									A.{$this->store->field_campaignaudio_productionStatus} AS productionStatus,
									A.{$this->store->field_campaignaudio_filename} AS filename,
									A.{$this->store->field_campaignaudio_deadlineDate} AS productionDeadline,
									A.{$this->store->field_campaignaudio_startDate} AS audioStartDate,
									A.{$this->store->field_campaignaudio_endDate} AS audioEndDate,
									C.{$this->store->field_campaign_name} AS campaign,
									C.{$this->store->field_campaign_campaignID} AS campaignID,
									C.{$this->store->field_campaign_startDate} AS campaignStartDate,
									C.{$this->store->field_campaign_endDate} AS campaignEndDate,
									O.{$this->store->field_contract_name} AS contract,
									O.{$this->store->field_contract_contractID} AS contractID,
									O.{$this->store->field_contract_contractStatus} AS contractStatus,
									L.{$this->store->field_client_name} AS client,
									L.{$this->store->field_client_clientID} AS clientID,
									S.{$this->store->field_spot_priority} AS priority,
									S.{$this->store->field_spot_spotID} AS spotID,
									T.{$this->store->field_talent_talentID} AS talentID,
									CONCAT(D.{$this->store->field_detail_firstName},' ',D.{$this->store->field_detail_lastName}) AS talent,
									D.{$this->store->field_detail_gender} AS gender,
									P.{$this->store->field_producttype_name} AS productType,
									P.{$this->store->field_producttype_productTypeID} AS productTypeID
							FROM ({$this->store->table_traffic_spot} S, {$this->store->table_traffic_campaignaudio} A)
							LEFT OUTER JOIN {$this->store->table_traffic_campaign} C ON A.{$this->store->field_campaignaudio_campaignID} = C.{$this->store->field_campaign_campaignID}
							LEFT OUTER JOIN {$this->store->table_traffic_contract} O ON A.{$this->store->field_campaignaudio_contractID} = O.{$this->store->field_contract_contractID}
							LEFT OUTER JOIN {$this->store->table_traffic_client} L ON A.{$this->store->field_campaignaudio_clientID} = L.{$this->store->field_client_clientID}
							LEFT OUTER JOIN {$this->store->table_traffic_campaignaudiotalent} E ON A.{$this->store->field_campaignaudio_campaignAudioID} = E.{$this->store->field_campaignaudiotalent_campaignAudioID}
							LEFT OUTER JOIN {$this->store->table_traffic_talent} T ON T.{$this->store->field_talent_talentID} = E.{$this->store->field_campaignaudiotalent_talentID}
							LEFT OUTER JOIN {$this->store->table_detail} D ON T.{$this->store->field_talent_actorID} = D.{$this->store->field_detail_actorID}
							LEFT OUTER JOIN {$this->store->table_traffic_campaignaudioproducttype} Y ON A.{$this->store->field_campaignaudio_campaignAudioID} = Y.{$this->store->field_campaignaudioproducttype_campaignAudioID}
							LEFT OUTER JOIN {$this->store->table_traffic_producttype} P ON Y.{$this->store->field_campaignaudioproducttype_productTypeID} = P.{$this->store->field_producttype_productTypeID}
							WHERE S.{$this->store->field_spot_mediaID} = A.{$this->store->field_campaignaudio_mediaID}
							AND S.{$this->store->field_spot_dateTime} >= "$cell_day $row_start"
							AND S.{$this->store->field_spot_dateTime} < "$cell_next_day $row_next"
							ORDER BY priority, spotID
EOQ;
						$spots = sysdb::query_assoc($query,false);
						$warn = array();
						$error = array();
						$timeoccupied = 0;

						foreach ($spots as $spotline) {
							$timeoccupied += $spotline['duration'];
							$warn[$spotline['campaignAudioID']] = '';
							$error[$spotline['campaignAudioID']] = '';

							if ($spotline['filename'] != ''
								&& $spotline['productionStatus'] == 'Approved'
								&& ($spotline['contractStatus'] == 'Approved'
									|| $spotline['contractStatus'] == 'Invoiced'
									|| $spotline['contractStatus'] == 'Paid')
							) {
								// Spot is approved with uploaded media and is ready to play out.
							} else {

								// Roughly in severity then procedure order.

								// File: NO;
								if ($spotline['filename'] == '') {
									$error_text = '';
									if (strtotime("now") >= strtotime($spotline['productionDeadline'])) {
										$error_text .= 'Production deadline has passed with no audio uploaded';
									} else {
										$error_text .= 'No audio is uploaded';
									}
									if ($spotline['contractStatus'] == 'Proposed'
										|| $spotline['contractStatus'] == 'Cancelled'
									) {
										$error_text .= ' and Contract Status is not Approved or Paid or Invoiced';
									}
									if ($spotline['productionStatus'] != 'Approved') {
										$error_text .= ' and Production Status is not Approved';
									}

									$error[$spotline['campaignAudioID']] = $error_text;
									continue;
								}

								// File: YES; Contract: NO; Production: NO;
								if ($spotline['filename'] != ''
									&& $spotline['productionStatus'] != 'Approved'
									&& ($spotline['contractStatus'] == 'Proposed'
										|| $spotline['contractStatus'] == 'Cancelled')
									) {
									$error[$spotline['campaignAudioID']] = 'Audio is uploaded but Contract Status and Production Status are not Approved';
									continue;
								}

								// File: YES; Contract: NO; Production: YES;
								if ($spotline['filename'] != ''
									&& $spotline['productionStatus'] == 'Approved'
									&& ($spotline['contractStatus'] == 'Proposed'
										|| $spotline['contractStatus'] == 'Cancelled')
									) {
									$error[$spotline['campaignAudioID']] = 'Audio is uploaded but Contract Status is not Approved or Paid or Invoiced';
									continue;
								}

								// File: YES; Contract: YES; Production: NO;
								if ($spotline['filename'] != ''
									&& $spotline['productionStatus'] != 'Approved'
									&& ($spotline['contractStatus'] == 'Approved'
										|| $spotline['contractStatus'] == 'Invoiced'
										|| $spotline['contractStatus'] == 'Paid')
									) {
									$error[$spotline['campaignAudioID']] = 'Audio is uploaded but Production Status is not Approved';
									continue;
								}

								if (strtotime("now") >= strtotime("-3 day",strtotime($cell_day))
									&& $spotline['productionStatus'] != 'Approved') {
									$error[$spotline['campaignAudioID']] = 'Air date is in less than three days and Production Status is not Approved';
									continue;
								}

								if (strtotime("now") >= strtotime("-3 day",strtotime($cell_day))
									&& !in_array($spotline['contractStatus'],array('Approved','Paid','Invoiced'))) {
									$error[$spotline['campaignAudioID']] = 'Air date is in less than three days and Contract Status is not Approved or Paid or Invoiced';
									continue;
								}

								if ($spotline['duration'] == 0) {
									$error[$spotline['campaignAudioID']] = 'Audio Duration is 0!';
									continue;
								}

								if (strtotime($cell_day) < strtotime($spotline['productionDeadline'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled before production deadline';
									continue;
								}

								if (!in_array($spotline['contractStatus'],array('Approved','Paid','Invoiced'))) {
									$warn[$spotline['campaignAudioID']] = 'Contract Status is not Approved or Paid or Invoiced';
									continue;
								}

								if ($spotline['productionStatus'] != 'Approved') {
									$warn[$spotline['campaignAudioID']] = 'Production Status is not Approved';
									continue;
								}

								if (strtotime($cell_day) < strtotime($spotline['audioStartDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled before allocated Audio start date';
									continue;
								}

								if (strtotime($cell_day) > strtotime($spotline['audioEndDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled after allocated Audio end date';
									continue;
								}

								if (strtotime($cell_day) < strtotime($spotline['campaignStartDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled before allocated Campaign start date';
									continue;
								}

								if (strtotime($cell_day) > strtotime($spotline['campaignEndDate'])) {
									$warn[$spotline['campaignAudioID']] = 'Spot is scheduled after allocated Campaign end date';
									continue;
								}
							}
						}

						if ($timeoccupied > $maxtime) {
						}

						//if ($timeoccupied > 0) echo $query;

						$box[$i][$j] = $doc->createElement('td');
						$box[$i][$j]->setAttribute('id', "traffic_box[{$i}][{$j}]");
						$box[$i][$j]->setAttribute('class', 'traffic_daily');
						if ($rowspan != 1) $box[$i][$j]->setAttribute('rowspan', $rowspan);

						$styleshades = 20;
						$timeremaining = $maxtime-$timeoccupied;

						if ($timeremaining < 0) {
							$error[-1] = 'More than '.$maxtime.' s allocated to the hour.';
						}


						$div = $doc->createElement('div');
//						$div->setAttribute('onclick', 'popupbox(this,'.$i.','.$j.');');
						//$div->setAttribute('onmouseout', 'popoutbox(this);');

						if (20-ceil(( ($timeremaining / $maxtime)*100)/5) > 20) $styleshade = 20; else $styleshade = 20-ceil(( ($timeremaining / $maxtime)*100)/5);
						$shadetype = '';
						if ($timeremaining < 0) { $styleshade = 20; $shadetype = '_full'; }
						else if (sizeof(array_filter($error)) > 0) $shadetype = '_error';
						else if (sizeof(array_filter($warn)) > 0) $shadetype = '_warn';
						if (isset($highlightoverlay) && !in_array($cell_day." ".$row_start,$highlightoverlay))
							$shadetype = '_grey';
						$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");

						$div->appendChild($doc->createTextNode($timeremaining.'s'));
						// //$div->appendChild($doc->createTextNode($next_known_slot_in_column));
						$box[$i][$j]->appendChild($div);
						$line[$i]->appendChild($box[$i][$j]);

						$box[$i][$j] = $doc->createElement('td');
						$box[$i][$j]->setAttribute('id', "traffic_box[{$i}][{$j}]");
						$div = $doc->createElement('div');
						$div->setAttribute('id', "traffic_div");
						if ($timeremaining < 0)
							$div->setAttribute('class', "traffic_shade{$styleshade}$shadetype");
						// $popupdiv = $doc->createElement('div');
						// $popupdiv->setAttribute('class', 'popup_small');
						// $popupdiv->setAttribute('id', 'popup['.$i.']['.$j.']');
						// $popupdiv->setAttribute('visibility', 'hidden');
						$div->appendChild($popuptable = $doc->createElement('table'));
						// $popuptable->appendChild($tr = $doc->createElement('tr'));
						// $tr->appendChild($td = $doc->createElement('td'));
//						$td->appendChild($span = $doc->createElement('span'));
//						$span->setAttribute('class', 'link_close_small');
//						$span->setAttribute('style', 'float: right;');
//						$span->setAttribute('onclick', 'popoutbox();');
//						$span->appendChild($doc->createTextNode(' '));
//						$td->appendChild($doc->createTextNode(' '));


						$query = <<<EOQ
							SELECT DISTINCT {$this->store->field_slot_time} AS time
							FROM {$this->store->table_traffic_slot}
							WHERE {$this->store->field_slot_startDate} <= '$cell_day'
							AND ({$this->store->field_slot_endDate} IS NULL OR {$this->store->field_slot_endDate} >= '$cell_next_day')
							AND {$this->store->field_slot_dow} = '$cell_dow'
							AND {$this->store->field_slot_time} >= '$row_start'
EOQ;
						if ($row_next != '00:00:00') $query .= " AND {$this->store->field_slot_time} < '$row_next'";
						$query .= ' ORDER BY time';
						$slots = sysdb::query2vector($query, 'time');

						if (sizeof($slots) <= 0) {
							$popuptable->appendChild($tr = $doc->createElement('tr'));
							$tr->appendChild($td = $doc->createElement('td'));
							$td->appendChild($doc->createElement('No slots in this hour.'));
						}

						$currentTimestamp = date("U");

						foreach ($slots as $slottime) {
							$popuptable->appendChild($tr = $doc->createElement('tr'));
							$tr->appendChild($td = $doc->createElement('td'));
							$td->appendChild($slottable = $doc->createElement('table'));

							$slottable->setAttribute('class','traffic_popup');
							$slottable->appendChild($tr = $doc->createElement('tr'));
							// $tr->appendChild($th = $doc->createElement('th'));
							// $th->setAttribute('class','title');

							// // Human readable date formatting: Y-m-d => d/m/Y
							// $slot_date_exploded = explode("-",$cell_day);
							// krsort($slot_date_exploded);
							// $print_date = implode("/",$slot_date_exploded);

							// $th->appendChild($doc->createTextNode($slottime.' '.$print_date));
							// $th->setAttribute('colspan','5');

							if (sizeof($spots) <= 0) {
								$slottable->appendChild($tr = $doc->createElement('tr'));
								$tr->appendChild($td = $doc->createElement('td'));
								$td->appendChild($doc->createTextNode('No spots'));
								$td->setAttribute('class',"blue");
//								$td->setAttribute('colspan','5');
							} else {
								$slottable->appendChild($tr = $doc->createElement('tr'));
								foreach (array("Reorder","Duration","Client","Contract","Campaign","Audio","Talent","Gender","Sector","Product Type") as $header) {
									$tr->appendChild($th = $doc->createElement('th'));
									$th->appendChild($doc->createTextNode($header));
								}

								foreach ($spots as $spotline) {
									$clientID = $spotline['clientID'];
									$query = <<<EOQ
										SELECT R.{$this->store->field_sector_name} AS sector,
											R.{$this->store->field_sector_sectorID} AS sectorID
										FROM {$this->store->table_traffic_clientsector} K,
											{$this->store->table_traffic_sector} R
										WHERE K.{$this->store->field_clientsector_clientID} = '$clientID'
										AND K.{$this->store->field_clientsector_sectorID} = R.{$this->store->field_sector_sectorID}
										ORDER BY sector
EOQ;
									$sectors = sysdb::query2keyedarray($query,array('sectorID'),array('sector'));

									$slottable->appendChild($tr = $doc->createElement('tr'));
									// TODO: Add ,'Talent','Sector','SalesRep','ProductType','Reschedule'
									foreach (array('Priority','Duration','Client','Contract','Campaign','CampaignAudio','Talent','Gender','Sector','ProductType') as $field) {
										$tr->appendChild($td = $doc->createElement('td'));
										if ($error[$spotline['campaignAudioID']] != '') {
											$td->setAttribute('class',"error");
											$td->setAttribute('title',$error[$spotline['campaignAudioID']]);
										}
										else if ($warn[$spotline['campaignAudioID']] != '') {
											$td->setAttribute('class',"warn");
											$td->setAttribute('title',$warn[$spotline['campaignAudioID']]);
										}
										$idname = strtolower($field{0}).substr($field,1);
										if ($field != 'Duration' && $field != 'Priority' && $field != 'Talent' && $field != 'Gender' && $field != 'Sector') {
											$td->appendChild($a = module::link_to_script_dom_unappended($doc,'','',
															array('item'=>$field,
																  'action'=>'view',
																  'id'=>$spotline[$idname.'ID']),
																  '',''));
											$a->appendChild($doc->createTextNode(utf8_decode($spotline[$idname])));
										} elseif ($field == 'Talent') {
											$td->appendChild($a = module::link_to_script_dom_unappended($doc,'','',
															array('item'=>'Talent',
																  'action'=>'view',
																  'id'=>$spotline['talentID']),
																  '',''));
											$a->appendChild($doc->createTextNode($spotline[$idname]));
										} elseif ($field == 'Gender') {
											// $sex = strtolower($spotline['gender']);
											// $td->setAttribute('class',"gender_".$sex);
											$td->appendChild($doc->createTextNode($spotline[$idname]));
										} elseif ($field == 'Sector') {
											if (sizeof($sectors) > 0) {
												// Because there are multiple sectors per client, we need to combine them in one cell.
												foreach ($sectors as $sectorID => $sector) {
													$td->appendChild($a = module::link_to_script_dom_unappended($doc,'','',
																	array('item'=>'Sector',
																		  'action'=>'view',
																		  'id'=>$sectorID),
																		  '',''));
													$a->appendChild($doc->createTextNode($sector));
													$td->appendChild($doc->createElement('br'));
												}
											}
										} else if ($field == 'Priority') {
											$divPriority = $doc->createElement('div');
											$spanPriorityUp = $doc->createElement('span');
											$spanPriorityUp->setAttribute('class', 'link_up_small');
											$spanPriorityUp->appendChild(module::link_to_script_dom($doc,'Prioritize Up','',
															array('item'=>globalize('item',get_class($this)),
																  'num_of_days'=>$num_of_days,
																  'num_of_hours'=>$num_of_hours,
																  'hour_start'=>$display_start_time,
																  'day_start'=>$display_start_day->format('Y-m-d'),
																  'action'=>'reorder',
																  'spotID'=>$spotline['spotID'],
																  'shift_value'=>'-1',
																  '#'=>'traffic_row_lead['.$i.']'),
																  'Prioritize Up',''));
											$divPriority->appendChild($spanPriorityUp);

											// // Temporary printout of actual priority value.
											// $spanPriorityText = $doc->createElement('span');
											// $spanPriorityText->appendChild($doc->createTextNode($spotline[$idname]));
											// $divPriority->appendChild($spanPriorityText);

											$spanPriorityDown = $doc->createElement('span');
											$spanPriorityDown->setAttribute('class', 'link_down_small');
											$spanPriorityDown->appendChild(module::link_to_script_dom($doc,'Prioritize Down','',
															array('item'=>globalize('item',get_class($this)),
																  'num_of_days'=>$num_of_days,
																  'num_of_hours'=>$num_of_hours,
																  'hour_start'=>$display_start_time,
																  'day_start'=>$display_start_day->format('Y-m-d'),
																  'onclick'=>'popupbox(this,'.$i.','.$j.');',
																  'action'=>'reorder',
																  'spotID'=>$spotline['spotID'],
																  'shift_value'=>'1',
															      '#'=>'traffic_row_lead['.$i.']'),
																  'Prioritize Down',''));
											$divPriority->appendChild($spanPriorityDown);

											$spanSchedule = $doc->createElement('span');
											$spanSchedule->setAttribute('class', 'link_schedule_small');
											$spanSchedule->appendChild(module::link_to_script_dom($doc,'reschedule','',
															array('item'=>globalize('item',get_class($this)),
																  'view_days'=>$num_of_days,
																  'day_start'=>$display_start_day->format('Y-m-d'),
																  'action'=>'reschedule',
																  'id'=>$spotline['spotID']),
																  'Reschedule'));
											$divPriority->appendChild($spanSchedule);

											$td->appendChild($divPriority);
										} else {
											$td->appendChild($doc->createTextNode(utf8_decode($spotline[$idname])));
										}
									}

								}
								$slottable->appendChild($tr = $doc->createElement('tr'));
								$tr->appendChild($td = $doc->createElement('td'));
								$td->setAttribute('class',"blue");
	//							$td->setAttribute('colspan','4');
								$td->appendChild($doc->createTextNode('Total:'));
								$tr->appendChild($td = $doc->createElement('td'));
								if ($timeremaining < 0) {
									$td->setAttribute('class',"error");
								} else {
									$td->setAttribute('class',"blue");
								}
								$td->appendChild($doc->createTextNode($timeoccupied));
							}

							$slotTimestamp = strtotime($cell_day.' '.$slottime);

							if ($mode == "CampaignAudio" && $campaignAudioID != '' && $currentTimestamp < $slotTimestamp) {
								$popuptable->appendChild($tr = $doc->createElement('tr'));
								$tr->appendChild($td = $doc->createElement('td'));
								$td->appendChild($span = $doc->createElement('span'));
								$span->setAttribute('class','link_add_small');
								$span->appendChild(module::link_to_script_dom_unappended($doc,'Add Spot','',
												array('item'=>globalize('item',get_class($this)),
													  'num_of_days'=>$num_of_days,
													  'num_of_hours'=>$num_of_hours,
													  'hour_start'=>$display_start_time,
													  'day_start'=>$display_start_day->format('Y-m-d'),
													  'action'=>'Add Spot',
													  'campaignAudioID'=>$campaignAudioID,
													  'mode'=>$mode,
													  'spot'=>$cell_day.' '.$slottime
													 ),'Add Spot','link_add_small'));
								$td->setAttribute('colspan','5');
							}
						}

						$box[$i][$j]->appendChild($div);

						$line[$i]->appendChild($box[$i][$j]);
					}
					if ($row_next > $row_start) {
						$date_counter->modify("+1 day");
					}
				}
				$tblmain->appendChild($line[$i]);
			}
			$grid->appendChild($tblmain);

			// Check for program component dependency.
			if (file_exists(ROOT_COMPONENTS.'programs/moduleconfig.php')) {
				// This HTML link is the temporary link to test HTML export by program
				$exportHTML = module::link_to_script_dom($doc,'Export by Programs','programlogs2html.php',array('dates'=>$export_day),true,true,'Export by Programs');
				$grid->appendChild($exportHTML);
			}

		}
        return $form;
    }

   /**
	* Rotates an array with keys until the search value is the first value in the array.
	*
	* If the search value does not exist, it just returns the same array.
	*/
    public function rotateWithKeys($array,$search_value) {
        $search_key = array_search($search_value,$array);
        if ($search_key == FALSE) return($array);
        //We can't use array_slice because we don't know where the key is in the array if non-numeric keys
        $newarray = array();
        $key_found = false;
        foreach($array as $key=>$value) {
            if ($key == $search_key) $key_found = true;
            if ($key_found) {
                $newarray[$key] = $value;
            }
        }

        foreach($array as $key=>$value) {
            if ($key == $search_key) break;
            $newarray[$key] = $value;
        }

        return($newarray);
    }

   /**
	* Rotates an array until the search value is the first value in the array.
	*
	* If the search value does not exist, it just returns the same array.
	*/
    public function rotate($array,$search_value) {
        $search_key = array_search($search_value,$array);
        if ($search_key == FALSE) {
            echo 'Search key not found.';
            return($array);
        }
        //We can't use array_slice because we don't know where the key is in the array if non-numeric keys
        $newarray = array();
        $key_found = false;
        foreach($array as $key=>$value) {
            if ($key == $search_key) $key_found = true;
            if ($key_found) {
                $newarray[] = $value;
            }
        }

        foreach($array as $key=>$value) {
            if ($key == $search_key) break;
            $newarray[] = $value;
        }

        return($newarray);
    }

    public function add() {
    }

    public function save() {
    }

    public function delete() {
    }

    public function search($doc,$string) {
    }

    public function headers($doc) {
       $moduleID = globalize('moduleID');
       $script1 = $doc->createElement('script');
       $script1->setAttribute('language', 'javascript');
       $script1->setAttribute('src', WWWROOT."stylesheet.php?moduleID=".$moduleID."&file=Traffic.js");
       $script1->appendChild($doc->createTextNode(''));

       $script2 = $doc->createElement('script');
       $script2->setAttribute('language', 'javascript');
       $script2->setAttribute('src', WWWROOT."stylesheet.php?moduleID=".$moduleID."&file=table_edgehighlight.js");
       $script2->appendChild($doc->createTextNode(''));

       $script3 = $doc->createElement('script');
       $script3->setAttribute('language', 'javascript');
       $script3->setAttribute('src', WWWROOT."stylesheet.php?moduleID=".$moduleID."&file=table_countticks.js");
       $script3->appendChild($doc->createTextNode(''));

       return(array($script1,$script2,$script3));
//       return(array($script2));
    }

   /** Changes the priority of a spot, and all other spots in a time slot accordingly. */
    public function reprioritizeSpots($spotID, $shift_value) {
		/** @todo Change calls to this function to reference Spot() class directly, as it doesn't return elements for display. */
		return(Spot::reprioritize($spotID, $shift_value));
    }

   /** Deletes a spot, and changes the priority of all other spots in a time slot accordingly. */
    public function removeSpot($spotID) {
		/** @todo Change calls to this function to reference Spot() class directly, as it doesn't return elements for display. */
		return(Spot::remove($spotID));
    }

    public function reschedule($doc, $id) {
        return(Schedule::displayGridTickboxes($doc,$id));
    }

}
?>
