<?php
// $Id$

class TrafficAllContractsPlugin {
	private $store;
	private $component;
	private $module;
	private $plugin;

	function __construct() {
		$this->title = 'All sponsorship contracts';
		$this->description = 'Displays all sponsorship contracts that are not finalised.';
	}

    public function setComponent($component) {
        $this->component = $component;
    }

    public function setModule($module) {
        $this->module = $module;
    }

    public function setPlugin($plugin) {
        $this->plugin = $plugin;
    }

    public function getComponent() {
        return $this->component;
    }

    public function getModule() {
        return $this->module;
    }

    public function getPlugin() {
        return $this->plugin;
    }

	public function TrafficAllContractsPlugin() {
		$component = $this->component;

		// Find module storage methods.
		$dir = DIRECTORY_SEPARATOR;
		require_once(ROOT_COMPONENTS.$component.$dir.'moduleconfig.php');
		$this->store = new trafficStorage();

		$doc = new DOMDocument();
		$doc->formatOutput = true;

		$container = $doc->createElement('div');
		$container->setAttribute('class','module_right');

		$sortby = globalize('sortby');
		if (!isset($sortby))
			$sortby = 'contractname';
		else {
			switch($sortby) {
				case 'contractname':
					break;
				case 'contractstatus':
					$sortby = 'contractstatus';
					break;
				case 'startdate':
					$sortby = 'startdate';
					break;
				case 'salesrep':
					$sortby = 'salesrep';
					break;
				default:
					$sortby = 'startdate';
					break;
			}
		}

		function AllContractsPlugin_header($doc) {
			$tr = $doc->createElement('tr');

			$th1 = $doc->createElement('th');
			$th2 = $doc->createElement('th');
			$th3 = $doc->createElement('th');
			$th4 = $doc->createElement('th');

			$th1->appendChild(module::link_to_script_dom($doc,'Contract #','',array('sortby'=>'name'),'Contract #'));
			$th2->appendChild(module::link_to_script_dom($doc,'Status','',array('sortby'=>'contractstatus'),'Status'));
			$th3->appendChild(module::link_to_script_dom($doc,'Start Date','',array('sortby'=>'startdate'),'Start Date'));
			$th4->appendChild($label = $doc->createTextNode('Sales Rep'));

			$tr->appendChild($th1);
			$tr->appendChild($th2);
			$tr->appendChild($th3);
			$tr->appendChild($th4);

			return $tr;
		}

		function AllContractsPlugin_field($field,$value) {
			if ($field == '2') {
				if ($value == 'Proposed') {
					$class = 'contractstatus_proposed';
					return $class;
				}
				if ($value == 'Approved') {
					$class = 'contractstatus_approved';
					return $class;
				}
				if ($value == 'Invoiced') {
					$class = 'contractstatus_invoiced';
					return $class;
				}
				if ($value == 'Paid') {
					$class = 'contractstatus_paid';
					return $class;
				}
				if ($value == 'Cancelled') {
					$class = 'contractstatus_cancelled';
					return $class;
				}
			}
		}

		function AllContractsPlugin_colgroups($doc) {
			$col1 = $doc->createElement('col');
			$col2 = $doc->createElement('col');
			$col3 = $doc->createElement('col');

			$colgroup = array($col1,$col2,$col3);

			return $colgroup;
		}

		/* All the functions need to be loaded up as variables, to avoid undefined variable errors from call_user_func_array() */
		$action_func = '';
		$footer_func = '';
		$header_func = 'AllContractsPlugin_header';
		$field_func = 'AllContractsPlugin_field';
		$col_func = 'AllContractsPlugin_colgroups';
		$colgroup = call_user_func_array($col_func,array($doc));
		$caption = "All sponsorship contracts";

		$ignore = array('0');

		$ids = '';

		$query = "SELECT I.contractID, I.name AS contractname, I.contractStatus as contractstatus, I.startDate as startdate ";
		$query .= "FROM ({$this->store->table_traffic_contract} I, {$this->store->table_traffic_client} C) ";
		$query .= "WHERE C.clientID = I.clientID ";
		$query .= "AND (I.contractStatus != 'Cancelled' && I.contractStatus != 'Paid') ";
		if (is_array($ids) && sizeof($ids) <= 0) { $query .= 'AND 0=1 '; } else if (is_array($ids) && sizeof($ids) > 0)
			$query .= "AND I.contractID IN (".implode(',',$ids).") ";
		if(isset($sortby))
			$query .= "ORDER BY ".$sortby;

		// Turn result query into a matrix.
		$matrix = sysdb::query2matrix($query,false);

		// Rotate the matrix 90 degrees so that each column is a vector within the matrix.
		$matrix_rotated_90 = sysdb::rotatematrix($matrix);

		// Perform data transformation on any column (vector), row by row (key by key).
		$contractNames = array();
		$startDates = array();
		$salesRepNames = array();
		if (!empty($matrix_rotated_90[0])) {
			foreach ($matrix_rotated_90[0] as $key=>$value) {
				$contractNames[$key] = module::link_to_script_dom($doc,$matrix_rotated_90[1][$key],'',array('moduleID'=>$this->module,'item'=>'Contract','action'=>'view','id'=>$value),$matrix_rotated_90[1][$key],'');
				$startDates[$key] = date("d-M-Y", strtotime($matrix_rotated_90[3][$key]));
				$contractID = $matrix_rotated_90[0][$key];
				$query = <<<EOQ
					SELECT CONCAT(D.{$this->store->field_detail_firstName},' ',D.{$this->store->field_detail_lastName}) as salesRepName,
						S.{$this->store->field_salesrep_salesRepID} as salesRepID
					FROM ({$this->store->table_detail} D, {$this->store->table_traffic_contractsalesrep} R, {$this->store->table_traffic_salesrep} S)
					WHERE R.{$this->store->field_contractsalesrep_contractID} = '$contractID'
					AND S.{$this->store->field_salesrep_salesRepID} = R.{$this->store->field_contractsalesrep_salesRepID}
					AND S.{$this->store->field_salesrep_actorID} = D.{$this->store->field_detail_actorID}
EOQ;
				$result = sysdb::query($query);
				$line = sysdb::fetch_assoc($result);
				$salesRepName = $line['salesRepName'];
				$salesRepID = $line['salesRepID'];

				$salesRepNames[$key] = module::link_to_script_dom($doc,$salesRepName,'',array('moduleID'=>$this->module,'item'=>'SalesRep','action'=>'view','id'=>$salesRepID),'');
			}
		}

		// Replace the original matrix column(s) with the new the vector(s).
		$matrix_rotated_90[1] = $contractNames;
		$matrix_rotated_90[3] = $startDates;
		$matrix_rotated_90[4] = $salesRepNames;

		// Rotate the new matrix 270 degrees to put it back the right way.
		$matrix_rotated_180 = sysdb::rotatematrix($matrix_rotated_90);
		$matrix_rotated_270 = sysdb::rotatematrix($matrix_rotated_180);
		$matrix_upright = sysdb::rotatematrix($matrix_rotated_270);

		$containertable = $doc->createElement('div');
		$containertable->setAttribute('id', 'inline_table');

		$table = sysdb::dom_matrix2table
		(
			$doc,
			$matrix_upright,
			false,
			'',
			'',
			$ignore,
			'',
			$header_func,
			array('table'=>'list','tr'=>'even','td'=>''),
			$caption,
			$colgroup,
			$field_func
		);

		$doc->appendChild($table);

		echo $doc->saveXML();
	}
}
?>