<?php
// $Id$

class TrafficAllProductionPlugin {
	private $store;
	private $component;
	private $module;
	private $plugin;

	function __construct() {
		$this->title = 'All sponsorship production deadlines';
		$this->description = 'Displays all sponsorship production deadlines.';
	}

    public function setComponent($component) {
        $this->component = $component;
    }

    public function setModule($module) {
        $this->module = $module;
    }

    public function setPlugin($plugin) {
        $this->plugin = $plugin;
    }

    public function getComponent() {
        return $this->component;
    }

    public function getModule() {
        return $this->module;
    }

    public function getPlugin() {
        return $this->plugin;
    }

	public function TrafficAllProductionPlugin() {
		$component = $this->component;

		// Find module storage methods.
		$dir = DIRECTORY_SEPARATOR;
		require_once(ROOT_COMPONENTS.$component.$dir.'moduleconfig.php');
		$this->store = new trafficStorage();

		$doc = new DOMDocument();
		$doc->formatOutput = true;

		$container = $doc->createElement('div');
		$container->setAttribute('class','module_right');

		$sortby = globalize('sortby');
		if (!isset($sortby))
			$sortby = 'name';
		else {
			switch($sortby) {
				case 'name':
					break;
				case 'deadline':
					$sortby = 'deadline';
					break;
				case 'status':
					$sortby = 'productionStatus, name';
					break;
				case 'producerID':
					$sortby = 'producerID, name';
					break;
				default:
					$sortby = 'deadline';
					break;
			}
		}

		function AllProductionPlugin_header($doc) {
			$tr = $doc->createElement('tr');

			$th1 = $doc->createElement('th');
			$th2 = $doc->createElement('th');
			$th3 = $doc->createElement('th');
			$th4 = $doc->createElement('th');

			$th1->appendChild(module::link_to_script_dom($doc,'Name','',array('sortby'=>'name'),'Name'));
			$th2->appendChild(module::link_to_script_dom($doc,'Deadline','',array('sortby'=>'deadline'),'Deadline'));
			$th3->appendChild(module::link_to_script_dom($doc,'Status','',array('sortby'=>'status'),'Status'));
			$th4->appendChild(module::link_to_script_dom($doc,'Producer','',array('sortby'=>'producerID'),'Producer'));

			$tr->appendChild($th1);
			$tr->appendChild($th2);
			$tr->appendChild($th3);
			$tr->appendChild($th4);

			return $tr;
		}

		function AllProductionPlugin_field($field,$value) {
			if ($field == '4') {
				if (strtotime("$value") < strtotime("now")) {
					$class = 'contractstatus_cancelled';
					return $class;
				}
			}
			if ($field == '5') {
				if ($value == 'Pending Draft Approval') {
					$class = 'audiostatus_draft';
					return $class;
				}
				if ($value == 'In Production') {
					$class = 'audiostatus_production';
					return $class;
				}
				if ($value == 'Pending Internal Approval') {
					$class = 'audiostatus_pending_internal';
					return $class;
				}
				if ($value == 'Pending Client Approval') {
					$class = 'audiostatus_pending_external';
					return $class;
				}
				if ($value == 'Approved') {
					$class = 'audiostatus_approved';
					return $class;
				}
			}
		}

		function AllProductionPlugin_colgroups($doc) {
			$col1 = $doc->createElement('col');

			$col2 = $doc->createElement('col');
			$col2->setAttribute('width', '80px');

			$col3 = $doc->createElement('col');
			$col3->setAttribute('width', '155px');

			$colgroup = array($col1,$col2,$col3);

			return $colgroup;
		}

		/* All the functions need to be loaded up as variables, to avoid undefined variable errors from call_user_func_array() */
		$action_func = '';
		$footer_func = 'AllProductionPlugin_footer';
		$header_func = 'AllProductionPlugin_header';
		$field_func = 'AllProductionPlugin_field';
		$col_func = 'AllProductionPlugin_colgroups';
		$colgroup = call_user_func_array($col_func,array($doc));
		$caption = "All sponsorship production deadlines";

		$ignore = array('0','2','3');

		$ids = '';

		$query = "SELECT A.campaignAudioID, A.name, ";
		$query .= "A.campaignID, G.name as campaignName, ";
		$query .= "A.deadlineDate as deadline, A.productionStatus as productionStatus, ";
		$query .= "A.producerID as producerID ";
		$query .= "FROM ({$this->store->table_traffic_campaign} G, {$this->store->table_traffic_campaignaudio} A, {$this->store->table_traffic_contract} O)";
		$query .= " WHERE G.campaignID = A.campaignID";
		$query .= " AND O.contractID = A.contractID";
		$query .= " AND (O.contractStatus = 'Approved' || O.contractStatus = 'Invoiced' || O.contractStatus = 'Paid')";
		$query .= " AND ((A.deadlineDate < TIMESTAMP(NOW()) && (A.productionStatus != 'Approved' && A.productionStatus != 'Pending Internal Approval' && A.productionStatus != 'Pending Client Approval'))";
		$query .= " || A.deadlineDate > TIMESTAMP(NOW()))";
		if (is_array($ids) && sizeof($ids) <= 0) { $query .= ' AND 0=1'; } else if (is_array($ids) && sizeof($ids) > 0)
			$query .= " AND A.campaignAudioID IN (".implode(',',$ids).") ";
		if(isset($sortby))
			$query .= " ORDER BY ".$sortby;

		// Turn result query into a matrix.
		$matrix = sysdb::query2matrix($query,false);

		// Rotate the matrix 90 degrees so that each column is a vector within the matrix.
		$matrix_rotated_90 = sysdb::rotatematrix($matrix);

		// Perform data transformation on any column (vector), row by row (key by key).
		$audioNames = array();
		$campaignNames = array();
		$deadlineDates = array();
		$producerNames = array();
		if (!empty($matrix_rotated_90[0])) {
			foreach ($matrix_rotated_90[0] as $key=>$value) {
				$audioNames[$key] = module::link_to_script_dom($doc,$matrix_rotated_90[1][$key],'',array('moduleID'=>$this->module,'item'=>'CampaignAudio','action'=>'view','id'=>$matrix_rotated_90[0][$key]),'');
				$campaignNames[$key] = module::link_to_script_dom($doc,$matrix_rotated_90[3][$key],'',array('moduleID'=>$this->module,'item'=>'Campaign','action'=>'view','id'=>$matrix_rotated_90[2][$key]),'');
				$deadlineDates[$key] = date("d-M-Y", strtotime($matrix_rotated_90[4][$key]));
				$producerID = $matrix_rotated_90[6][$key];
				$query = <<<EOQ
					SELECT CONCAT(D.{$this->store->field_detail_firstName},' ',D.{$this->store->field_detail_lastName}) as producerName
					FROM ({$this->store->table_detail} D, {$this->store->table_traffic_producer} P)
					WHERE P.{$this->store->field_producer_producerID} = '$producerID'
					AND P.{$this->store->field_producer_actorID} = D.{$this->store->field_detail_actorID}
EOQ;
				$producerName = sysdb::queryOne($query);
				$producerNames[$key] = module::link_to_script_dom($doc,$producerName,'',array('moduleID'=>$this->module,'item'=>'Producer','action'=>'view','id'=>$producerID),'');
			}
		}

		// Replace the original matrix column(s) with the new the vector(s).
		$matrix_rotated_90[1] = $audioNames;
		$matrix_rotated_90[3] = $campaignNames;
		$matrix_rotated_90[4] = $deadlineDates;
		$matrix_rotated_90[6] = $producerNames;

		// Rotate the new matrix 270 degrees to put it back the right way.
		$matrix_rotated_180 = sysdb::rotatematrix($matrix_rotated_90);
		$matrix_rotated_270 = sysdb::rotatematrix($matrix_rotated_180);
		$matrix_upright = sysdb::rotatematrix($matrix_rotated_270);

		$containertable = $doc->createElement('div');
		$containertable->setAttribute('id', 'inline_table');

		$table = sysdb::dom_matrix2table
		(
			$doc,
			$matrix_upright,
			false,
			'',
			'',
			$ignore,
			'',
			$header_func,
			array('table'=>'list','tr'=>'even','td'=>''),
			$caption,
			$colgroup,
			$field_func
		);

		$doc->appendChild($table);

		echo $doc->saveXML();
	}
}
?>