<?php
// $Id$

// This is an Export to HTML function designed to meet the very specific requirements of one organisation.
// It is intended to be a temporary printout for presenters, matched to replicate existing printouts
// from the Bluegum scheduling software. It is not designed to be a permanent feature of the traffic
// component, or at least it is expected to be replaced with log export features that are prettier
// and/or more practical.
//
// It can only be used in conjunction with the program component for Retromod, which is itself still
// under development.
//
// -- Ken McLean <ken at bentokit dot org>, 21/11/2009

	include_once('global.php');
    include_once('db.php');
	require_once('moduleconfig.php');

	// Turn desired dates into an array.
	$dates = explode(",",globalize('dates'));

	$store = new trafficStorage();

	$doc = new DOMDocument();
	$doc->formatOutput = true;

	// Check for program component dependency.
	if (file_exists(ROOT_COMPONENTS.'programs/moduleconfig.php')) {
		// Include dependency storage method.
		require_once(ROOT_COMPONENTS.'programs/moduleconfig.php');
		$remoteStore = new programStorage();

		// Start building the printable HTML page.
		$style = $doc->createElement('style');
		$text = $doc->createTextNode('table { width: 100%; } th { vertical-align: top; padding: 3px 10px 3px 10px; } td { vertical-align: top; padding: 2px 10px 2px 10px; } hr { page-break-after: always; color: white; } body { margin:0; padding:0; height:100%; font-family: courier new, sans-serif; } td.spot { font-weight: bold; }');
		$style->appendChild($text);
		$doc->appendChild($style);

		// Loop through each date requested from the Log class.
		$increment = 0;
		foreach ($dates as $date) {
			// Find the periodID of the program grid corresponding to the date.
			$query1 = <<<EOQ
				SELECT DISTINCT G.{$remoteStore->field_programs_grid_periodID}
				FROM ({$remoteStore->table_period} D,
					{$remoteStore->table_programs_grid} G
				)
				WHERE D.{$remoteStore->field_period_periodID} = G.{$remoteStore->field_programs_grid_periodID}
				AND (D.{$remoteStore->field_period_endDate} >= '$date'
					&& D.{$remoteStore->field_period_startDate} <= '$date'
				)
EOQ;

			$periodID = sysdb::queryOne($query1);

			$container = $doc->createElement('div');

			if ($periodID == '') {
				// Print an error if no program grid can be found.

				$h1 = $doc->createElement('h1');
				$text = $doc->createTextNode('Cannot find the equivalent program grid for the date '.$date);
				$h1->appendChild($text);
				$doc->appendChild($h1);

			} else {
				// Determine the day of the week (dow).
				$dow = date("l", strtotime($date));

				// Find a list of programs for this date.
				$query2 = <<<EOQ
					SELECT G.*,
						P.$remoteStore->field_programs_program_name
					FROM ($remoteStore->table_programs_program P,
						$remoteStore->table_programs_grid G
					)
					WHERE G.$remoteStore->field_programs_grid_periodID = '$periodID'
					AND G.$remoteStore->field_programs_grid_dow = '$dow'
					AND G.$remoteStore->field_programs_grid_programID = P.$remoteStore->field_programs_program_programID
					ORDER BY $remoteStore->field_programs_grid_startTime
EOQ;

				$result2 = sysdb::query($query2) or die("Query failed:".$query2);

				if (sysdb::num_rows($result2) <= 0) {
					$h1 = $doc->createElement('h1');
					$text = $doc->createTextNode('Cannot find the equivalent program grid for the date '.$date);
					$h1->appendChild($text);
					$doc->appendChild($h1);
				}

				// Build exported HTML data.
				while ($line2 = sysdb::fetch_assoc($result2)) {
					$display_date = date("d/m/Y", strtotime($date));

					$name = $line2['name'];
					$startTime = $line2['startTime'];
					$endTime = $line2['endTime'];

					$p = $doc->createElement('p');
					$p->appendChild($doc->createTextNode('DAILY LOG FOR AIRPLAY ON '.$dow.' the '.$display_date));
					$container->appendChild($p);

					$p = $doc->createElement('p');
					$p->appendChild($doc->createTextNode('============================'));
					$container->appendChild($p);

					$table = $doc->createElement('table');
//					$table->setAttribute('border','1'); // Used for viewing the table structure.

					$headertr = $doc->createElement('tr');
					$th1 = $doc->createElement('th');
					$th1->appendChild($doc->createTextNode('AIRTIME'));
					$th2 = $doc->createElement('th');
					$th2->appendChild($doc->createTextNode('CART NO.'));
					$th3 = $doc->createElement('th');
					$th3->appendChild($doc->createTextNode('CLIENT'));
					$th4 = $doc->createElement('th');
					$th4->appendChild($doc->createTextNode('CAMPAIGN'));
					$headertr->appendChild($th1);
					$headertr->appendChild($th2);
					$headertr->appendChild($th3);
					$headertr->appendChild($th4);
					$table->appendChild($headertr);

					$programtr = $doc->createElement('tr');
					$timetd = $doc->createElement('td');
					$label = $doc->createTextNode($startTime);
					$inputtd = $doc->createElement('td');
					$inputtd->setAttribute('colspan', '3');
					$input = $doc->createTextNode(strtoupper($name));
					$timetd->appendChild($label);
					$inputtd->appendChild($input);
					$programtr->appendChild($timetd);
					$programtr->appendChild($inputtd);
					$table->appendChild($programtr);

					// Make sure end time is within the day we're interested in.
					if ($endTime == '00:00:00') {
						$endTime = '23:59:59';
					}
					// Determine the available slots for this program.
					$query = <<<EOQ
						SELECT DISTINCT $store->field_slot_time AS time
						FROM $store->table_traffic_slot
						WHERE $store->field_slot_startDate <= '$date'
						AND ($store->field_slot_endDate IS NULL
							OR $store->field_slot_endDate >= '$date'
						)
						AND ($store->field_slot_time >= '$startTime'
							AND $store->field_slot_time < '$endTime'
						)
						ORDER BY time
EOQ;
					$result = sysdb::query($query) or die("Query failed:".$query);

					if (sizeof($result) > 0) {
						while ($line = sysdb::fetch_assoc($result)) {
							$slotTime = $line['time'];

							$slottr = $doc->createElement('tr');
							$timetd = $doc->createElement('td');
							$label = $doc->createTextNode($slotTime);
							$timetd->appendChild($label);
							$slottr->appendChild($timetd);

							// For each slot find the spots associated with that airdate.
							$query = "SELECT M.name AS campaignName, C.name AS clientName, ";
//							$query .= "S.dateTime, S.playedDateTime FROM ({$store->table_traffic_campaignaudio} A, {$store->table_traffic_spot} S) WHERE S.mediaID = A.mediaID AND (";
							$query .= "A.campaignAudioID FROM ({$store->table_traffic_campaignaudio} A, {$store->table_traffic_spot} S, {$store->table_traffic_campaign} M, {$store->table_traffic_client} C) WHERE S.mediaID = A.mediaID AND ";
							// $increment = 0;
							// foreach ($exportDates as $exportDate) {
								// if ($increment++ != 0)
									// $query .= " OR ";
							$query .= "S.dateTime = '".$date." ".$slotTime."'";
							$query .= " AND A.campaignID = M.campaignID";
							$query .= " AND A.clientID = C.clientID";
							// }
							$query .= " ORDER BY S.priority";

							$result3 = sysdb::query($query);

							$i = 0;
							// Check if there are any spots.
							if (sysdb::num_rows($result3) <= 0) {
								// Print no spots this hour.
								$carttd = $doc->createElement('td');
								$carttd->setAttribute('colspan', '3');
								$carttd->appendChild($doc->createTextNode('NO SPOTS FOR THIS HOUR'));
								$slottr->appendChild($carttd);
								$table->appendChild($slottr);
							} else {

								// Run a loop for each spot for the hour.
								while ($line3 = sysdb::fetch_assoc($result3)) {
									if ($i > 0) {
										// Create a new row for each spot.
										$table->appendChild($slottr);
										$slottr = $doc->createElement('tr');
									}
									$cartNo = $line3['campaignAudioID'];
									$clientName = $line3['clientName'];
									$campaignName = $line3['campaignName'];

									// Print the spot.
									$carttd = $doc->createElement('td');
									$carttd->setAttribute('class','spot');
									$carttd->appendChild($doc->createTextNode($cartNo));
									$slottr->appendChild($carttd);
									$clientNametd = $doc->createElement('td');
									$clientNametd->setAttribute('class','spot');
									$clientNametd->appendChild($doc->createTextNode($clientName));
									$slottr->appendChild($clientNametd);
									$campaignNametd = $doc->createElement('td');
									$campaignNametd->setAttribute('class','spot');
									$campaignNametd->appendChild($doc->createTextNode($campaignName));
									$slottr->appendChild($campaignNametd);

									$i++;
								}
								$table->appendChild($slottr);
							}

							// Add in the rowspan attribute.
							if ($i > 0) {
								$timetd->setAttribute('rowspan', $i);
							}
						}
					}
					$container->appendChild($table);

					$p = $doc->createElement('p');
					$p->appendChild($doc->createTextNode('============================ REPORT END ============================'));
					$container->appendChild($p);
					$p = $doc->createElement('p');
					$p->appendChild($doc->createTextNode('Printed on '.date('d/m/Y').' at time '.date('H:m:s')));
					$container->appendChild($p);

					// Force a page-break after each program using CSS on a horizontal rule.
					$hr = $doc->createElement('hr');
					$container->appendChild($hr);
				}
				$doc->appendChild($container);
			}
		}
	} else {
		// The program component is not installed.
		$h1 = $doc->createElement('h1');
		$text = $doc->createTextNode('Cannot export logs by program, because the program component dependency cannot be found. Please notify your system administrator of this error message.');
		$h1->appendChild($text);
		$doc->appendChild($h1);

	}

    echo $doc->saveXML();

?>