# $Id$

# /** Handles calls to traffic component storage methods. */
package traffic;

use strict;
use Carp;
use traffic::Storage;

our $AUTOLOAD;

my %fields = (
	component => undef,
	moduleID => undef,
);

# /** Autoload. */
sub AUTOLOAD {
	my $self = shift;
	my $type = ref($self)
		or croak "$self is not an object";

	my $name = $AUTOLOAD;
	# Strip fully-qualified portion.
	$name =~ s/.*://;

	unless (exists $self->{_permitted}->{$name} ) {
		croak "Can't access `$name' field in class $type";
	}

	if (@_) {
		return $self->{$name} = shift;
	} else {
		return $self->{$name};
	}
}

# /** Constructor. */
sub new {
	my $that = shift;
	my $class = ref($that) || $that;

	my $self = {
		_permitted => \%fields,
		%fields,
	};

	bless ($self, $class);
	return $self;
}

# /** Returns the storage class to share storage methods with other components. */
sub share_storage {
	my $self = shift;
	my $store = traffic::Storage->new();
	return $store;
}

# /** Help page. */
sub help {
	my($self, $args) = @_;
	# /** @todo If client argument exists print client's help method instead. */
	my $help_message = <<EOH;
This is the help for the traffic component of Retromod.

The playout component must be used with the argument of client.

Usage: update.pl traffic method [ arguments ]

  Method:
  help
    Returns this help page.
  share_storage
    Returns the storage class for the traffic component.

EOH
    print "$help_message\n";
}

# /** Destructor. */
sub DESTROY {
	my ($self) = @_;
}

1;