-- $Id$

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaign` (
  `campaignID` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `createdDateTime` datetime NOT NULL,
  `startDate` date NOT NULL,
  `endDate` date NOT NULL,
  `audioAllotted` int(11) NOT NULL,
  `spotsAllotted` int(11) NOT NULL,
  `contractID` int(11) NOT NULL,
  `clientID` int(11) NOT NULL,
  PRIMARY KEY (`campaignID`,`contractID`,`clientID`),
  KEY `fk_Campaign_Contract` (`contractID`,`clientID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaignassign` (
  `campaignID` int(11) NOT NULL,
  `id` int(11) NOT NULL,
  `type` enum('samID','salesRepID') NOT NULL
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaignaudio` (
  `campaignAudioID` int(11) NOT NULL AUTO_INCREMENT,
  `mediaID` int(11) DEFAULT NULL,
  `createdDateTime` datetime NOT NULL,
  `name` varchar(255) NOT NULL,
  `description` varchar(255) NOT NULL,
  `filename` varchar(255) NOT NULL,
  `mimetype` varchar(255) NOT NULL,
  `duration` varchar(255) NOT NULL,
  `productionStatus` enum('Pending Draft Approval','In Production','Pending Internal Approval','Pending Client Approval','Approved') NOT NULL DEFAULT 'Pending Draft Approval',
  `talentGender` enum('Unspecified','Male','Female','Mixed') NOT NULL DEFAULT 'Unspecified',
  `startDate` date NOT NULL,
  `endDate` date NOT NULL,
  `deadlineDate` date NOT NULL,
  `campaignID` int(11) NOT NULL,
  `contractID` int(11) NOT NULL,
  `clientID` int(11) NOT NULL,
  `producerID` int(11) DEFAULT NULL,
  PRIMARY KEY (`campaignAudioID`,`campaignID`,`contractID`,`clientID`),
  UNIQUE KEY `mediaID` (`mediaID`),
  KEY `fk_CampaignAudio_Campaign` (`campaignID`,`contractID`,`clientID`),
  KEY `fk_CampaignAudio_Producer` (`producerID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaignaudioproducttype` (
  `campaignAudioID` int(11) NOT NULL,
  `campaignID` int(11) NOT NULL,
  `contractID` int(11) NOT NULL,
  `clientID` int(11) NOT NULL,
  `productTypeID` int(11) NOT NULL,
  KEY `fk_CampaignAudioProductType_CampaignAudio` (`campaignAudioID`,`campaignID`,`contractID`,`clientID`),
  KEY `fk_CampaignAudioProductType_ProductType` (`productTypeID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaignaudiotalent` (
  `campaignAudioID` int(11) NOT NULL,
  `talentID` int(11) NOT NULL
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaignmaterial` (
  `campaignMaterialID` int(11) NOT NULL AUTO_INCREMENT,
  `mediaID` int(11) NOT NULL,
  `name` varchar(255) NOT NULL,
  `description` varchar(255) NOT NULL,
  `filename` varchar(255) NOT NULL,
  `mimetype` varchar(255) NOT NULL,
  `campaignID` int(11) NOT NULL,
  `contractID` int(11) NOT NULL,
  `clientID` int(11) NOT NULL,
  PRIMARY KEY (`campaignMaterialID`,`campaignID`,`contractID`,`clientID`),
  UNIQUE KEY `mediaID` (`mediaID`),
  KEY `fk_CampaignMaterial_Campaign` (`campaignID`,`contractID`,`clientID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_campaignpromotion` (
  `campaignPromotionID` int(11) NOT NULL AUTO_INCREMENT,
  `mediaID` int(11) NOT NULL,
  `name` varchar(255) NOT NULL,
  `description` varchar(255) NOT NULL,
  `filename` varchar(255) NOT NULL,
  `mimetype` varchar(255) NOT NULL,
  `campaignID` int(11) NOT NULL,
  `contractID` int(11) NOT NULL,
  `clientID` int(11) NOT NULL,
  PRIMARY KEY (`campaignPromotionID`,`campaignID`,`contractID`,`clientID`),
  UNIQUE KEY `mediaID` (`mediaID`),
  KEY `fk_CampaignPromotion_Campaign` (`campaignID`,`contractID`,`clientID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_client` (
  `clientID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) NOT NULL,
  `name` varchar(255) NOT NULL,
  `createdDateTime` datetime NOT NULL,
  `abn` varchar(11) DEFAULT NULL COMMENT 'ABN or ACN',
  `url` varchar(255) DEFAULT NULL COMMENT 'Website URL',
  PRIMARY KEY (`clientID`,`actorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_clientclientrep` (
  `clientID` int(11) NOT NULL,
  `clientRepID` int(11) NOT NULL,
  KEY `fk_ClientClientRep_Client` (`clientID`),
  KEY `fk_ClientClientRep_ClientRep` (`clientRepID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_clientrep` (
  `clientRepID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) NOT NULL,
  PRIMARY KEY (`clientRepID`,`actorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_clientsector` (
  `clientID` int(11) NOT NULL,
  `sectorID` int(11) NOT NULL,
  KEY `fk_ClientSector_Client` (`clientID`),
  KEY `fk_ClientSector_Sector` (`sectorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_contract` (
  `contractID` int(11) NOT NULL AUTO_INCREMENT,
  `createdDateTime` datetime NOT NULL,
  `startDate` date NOT NULL,
  `endDate` date NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `contractStatus` enum('Proposed','Approved','Invoiced','Paid','Cancelled') NOT NULL DEFAULT 'Proposed',
  `stationPresentsStatus` enum('true','false') NOT NULL DEFAULT 'false',
  `audioPurchased` int(11) NOT NULL,
  `spotsPurchased` int(11) NOT NULL,
  `services` varchar(255) NOT NULL,
  `price` float DEFAULT NULL,
  `priceGST` float DEFAULT NULL,
  `notes` varchar(255) NOT NULL,
  `clientID` int(11) NOT NULL,
  PRIMARY KEY (`contractID`,`clientID`),
  KEY `fk_Contract_Client` (`clientID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_contractclientrep` (
  `contractID` int(11) NOT NULL,
  `clientRepID` int(11) NOT NULL
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_contractsalesrep` (
  `contractID` int(11) NOT NULL,
  `salesRepID` int(11) NOT NULL
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_feedback` (
  `feedbackID` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) DEFAULT NULL,
  `login` varchar(255) DEFAULT NULL,
  `time` datetime DEFAULT NULL,
  `message` text,
  PRIMARY KEY (`feedbackID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_history` (
  `historyID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) DEFAULT NULL,
  `timestamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `id` int(11) DEFAULT NULL,
  `type` varchar(255) DEFAULT NULL,
  `action` varchar(255) DEFAULT NULL,
  `details` text,
  PRIMARY KEY (`historyID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_producer` (
  `producerID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) NOT NULL,
  PRIMARY KEY (`producerID`,`actorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_producttype` (
  `productTypeID` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `startDate` date NOT NULL,
  `endDate` date DEFAULT NULL,
  PRIMARY KEY (`productTypeID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_salesrep` (
  `salesRepID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) NOT NULL,
  PRIMARY KEY (`salesRepID`,`actorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_sam` (
  `samID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) NOT NULL,
  PRIMARY KEY (`samID`,`actorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_sector` (
  `sectorID` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `startDate` date NOT NULL,
  `endDate` date DEFAULT NULL,
  PRIMARY KEY (`sectorID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_slot` (
  `slotID` int(11) NOT NULL AUTO_INCREMENT,
  `startDate` date NOT NULL,
  `endDate` date DEFAULT NULL,
  `dow` enum('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday') NOT NULL DEFAULT 'Monday',
  `time` time NOT NULL,
  PRIMARY KEY (`slotID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_spot` (
  `spotID` int(11) NOT NULL AUTO_INCREMENT,
  `mediaID` int(11) NOT NULL,
  `dateTime` datetime NOT NULL,
  `playedDateTime` datetime DEFAULT NULL,
  `priority` int(11) DEFAULT NULL,
  `inactive` enum('false','true') DEFAULT 'false',
  PRIMARY KEY (`spotID`),
  KEY `fk_Spot_Media` (`mediaID`)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS `!tableprefix_traffic_talent` (
  `talentID` int(11) NOT NULL AUTO_INCREMENT,
  `actorID` int(11) NOT NULL,
  PRIMARY KEY (`talentID`,`actorID`)
) ENGINE=InnoDB;
