<?xml version="1.0" encoding="ISO-8859-1"?>
<!-- $Id$ -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
  xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns:date="http://exslt.org/dates-and-times"
  xmlns="http://www.w3.org/2000/svg">

  <xsl:param name="startDate"/>
  <xsl:param name="endDate"/>
  <xsl:param name="slotTime"/>

  <!-- calculate the difference in days between the first and last spot -->
  <xsl:variable name="difference" select="date:difference($startDate, $endDate)"/>
  <xsl:variable name="dayDiff">
    <xsl:call-template name="day-difference-strip">
      <xsl:with-param name="difference" select="$difference"/>
    </xsl:call-template>
  </xsl:variable>

  <!-- calculate the number of contract pages required to display entire schedule -->
  <xsl:variable name="pages">
    <xsl:choose>
      <xsl:when test="$dayDiff > 31">
        <xsl:value-of select="ceiling($dayDiff div 31)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="1"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:output method="xml" encoding="ISO-8859-1" indent="yes"/>

  <!-- Main that wraps the SVG output and adds page breaks -->
  <xsl:template match="/">

    <!-- start HTML wrapper output -->
    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
        <title>Contract <xsl:value-of select="/traffic/client/contract/name"/> (<xsl:value-of select="/traffic/client/name"/>)</title>
        <style type="text/css"><![CDATA[
          rect.grid-hor {
              fill: #808080
          }
          rect.grid-ver {
              fill: #808080
          }
          page {
              page-break-after: always
          }
          .period {
          }
        ]]></style>
      </head>
      <body>
        <!-- Loop for generating pages -->
        <xsl:call-template name="generate-pages"><xsl:with-param name="pageNumber" select="'1'"/></xsl:call-template>
      </body>
    </html>
    <!-- end HTML wrapper output -->
  </xsl:template>

  <!-- Template that builds the entire SVG image for output -->
  <xsl:template name="svg">

    <xsl:param name="beginDate"/>
    <xsl:param name="page"/>

    <svg version="1.2" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
     width="100%" height="100%" viewBox="30 20 530 750" xml:space="preserve">

        <!-- start contract header 620 794-->
      <text transform="matrix(1 0 0 1 188.3599 43.7197)" font-family="'Arial'" font-size="14.72" text-anchor="middle"><xsl:text>SPONSORSHIP CONTRACT</xsl:text></text>
      <text transform="matrix(0.8 0 0 1 200.1997 56.46)" font-family="'Arial'" font-size="8.28" text-anchor="middle"><xsl:text>If the details contained in this contract are satisfactory please sign and return immediately</xsl:text></text>
      <rect x="110.107" y="109.42" fill="#808080" width="276.647" height="0.9"/><!-- Client name -->
      <rect x="110.107" y="121.541" fill="#808080" width="276.647" height="0.899"/><!-- Client rep -->
      <rect x="462.302" y="95.36" fill="#808080" width="81.81" height="0.9"/><!-- sales rep header -->
      <rect x="461.834" y="108.42" fill="#808080" width="82.306" height="0.899"/><!-- date -->
      <rect x="110.107" y="133.66" fill="#808080" width="242.393" height="0.9"/><!-- address -->
      <rect x="276.6" y="145.78" fill="#808080" width="130.9" height="0.9"/><!-- mobile -->
      <rect x="408.82" y="157.9" fill="#808080" width="135.319" height="0.9"/><!-- email -->
      <rect x="461.834" y="121.56" fill="#808080" width="82.306" height="0.9"/><!-- contract no -->
      <rect x="100.24" y="177.799" fill="#808080" width="282.979" height="0.901"/><!-- campaign details -->
      <rect x="100.24" y="204.16" fill="#808080" width="282.979" height="0.9"/><!-- comments -->
      <rect x="110.107" y="145.78" fill="#808080" width="122.261" height="0.9"/><!-- phone -->
      <rect x="371.833" y="133.66" fill="#808080" width="110" height="0.9"/><!-- city -->
      <rect x="523.651" y="133.66" fill="#808080" width="20.46" height="0.9"/><!-- postcode -->
      <rect x="428.215" y="145.78" fill="#808080" width="115.925" height="0.9"/><!-- fax -->

      <rect x="38.78" y="244.06" fill="#808080" width="43.92" height="0.9"/><!-- audio id a -->
      <rect x="100.24" y="244.06" fill="#808080" width="282.979" height="0.9"/><!-- audio name a -->
      <rect x="396.36" y="244.06" fill="#808080" width="65.819" height="0.9"/><!-- audio start a -->
      <rect x="475.321" y="244.06" fill="#808080" width="65.818" height="0.9"/><!-- audio end a -->
      <rect x="38.78" y="256.181" fill="#808080" width="43.92" height="0.9"/><!-- audio name b -->
      <rect x="100.24" y="256.181" fill="#808080" width="282.979" height="0.9"/><!-- audio start b -->
      <rect x="396.36" y="256.181" fill="#808080" width="65.819" height="0.9"/><!-- audio start b -->
      <rect x="475.321" y="256.181" fill="#808080" width="65.818" height="0.9"/><!-- audio end b -->
      <rect x="38.78" y="268.3" fill="#808080" width="43.92" height="0.9"/><!-- audio name c -->
      <rect x="100.24" y="268.3" fill="#808080" width="282.979" height="0.9"/><!-- audio start c -->
      <rect x="396.36" y="268.3" fill="#808080" width="65.819" height="0.9"/><!-- audio start c -->
      <rect x="475.321" y="268.3" fill="#808080" width="65.818" height="0.9"/><!-- audio end c -->
      <rect x="38.78" y="280.42" fill="#808080" width="43.92" height="0.9"/><!-- audio name d -->
      <rect x="100.24" y="280.42" fill="#808080" width="282.979" height="0.9"/><!-- audio start d -->
      <rect x="396.36" y="280.42" fill="#808080" width="65.819" height="0.9"/><!-- audio start d -->
      <rect x="475.321" y="280.42" fill="#808080" width="65.818" height="0.9"/><!-- audio end d -->

      <rect x="110.24" y="296.08" fill="#808080" width="28" height="0.9"/><!-- audio purchased -->
      <rect x="225.26" y="296.719" fill="#808080" width="28" height="0.9"/><!-- spots purchased -->
      <rect x="323.5635" y="296.08" fill="#808080" width="60" height="0.9"/><!-- client sector -->
      <rect x="457.2598" y="296.719" fill="#808080" width="60" height="0.9"/><!-- product type -->

      <!-- start hiding of terms and conditions and agreement until the last page -->
      <xsl:if test="$page = $pages">
        <rect x="238.44" y="628.38" fill="#808080" width="65.82" height="0.9"/><!-- cost -->
        <rect x="343.72" y="628.38" fill="#808080" width="65.82" height="0.9"/><!-- gst -->
        <rect x="462.16" y="628.38" fill="#808080" width="65.821" height="0.9"/><!-- total cost -->

        <rect x="106.142" y="735.955" fill="#808080" width="208.019" height="0.939"/><!-- Client rep signature -->
        <rect x="403.26" y="739.954" fill="#808080" width="93.96" height="0.939"/><!-- sales rep footer -->
        <rect x="106.142" y="761.335" fill="#808080" width="208.019" height="0.941"/><!-- Client rep title -->
      </xsl:if>

      <!-- start structural lines for bounding boxes and grid etc. -->
      <rect x="342.8" y="29.66" width="1.84" height="18.86"/>
      <rect x="118.26" y="326.919" width="409.24" height="0.021"/>
      <rect x="37.86" y="27.86" width="1.84" height="20.66"/>
      <rect x="39.24" y="336.42" width="70.24" height="0.9"/>
      <rect x="133.16" y="317.44" width="0.02" height="18.98"/>
      <rect x="146.32" y="317.44" width="0.02" height="18.98"/>
      <rect x="159.48" y="317.44" width="0.02" height="18.98"/>
      <rect x="172.64" y="317.44" width="0.021" height="18.98"/>
      <rect x="185.8" y="317.44" width="0.02" height="18.98"/>
      <rect x="198.96" y="317.44" width="0.02" height="18.98"/>
      <rect x="212.12" y="317.44" width="0.02" height="18.98"/>
      <rect x="225.28" y="317.44" width="0.02" height="18.98"/>
      <rect x="238.44" y="317.44" width="0.021" height="18.98"/>
      <rect x="251.6" y="317.44" width="0.02" height="18.98"/>
      <rect x="264.76" y="317.44" width="0.02" height="18.98"/>
      <rect x="277.92" y="317.44" width="0.02" height="18.98"/>
      <rect x="291.08" y="317.44" width="0.021" height="18.98"/>
      <rect x="304.24" y="317.44" width="0.019" height="18.98"/>
      <rect x="317.4" y="317.44" width="0.02" height="18.98"/>
      <rect x="330.559" y="317.44" width="0.021" height="18.98"/>
      <rect x="343.72" y="317.44" width="0.021" height="18.98"/>
      <rect x="356.88" y="317.44" width="0.021" height="18.98"/>
      <rect x="370.04" y="317.44" width="0.019" height="18.98"/>
      <rect x="383.2" y="317.44" width="0.02" height="18.98"/>
      <rect x="396.36" y="317.44" width="0.02" height="18.98"/>
      <rect x="409.52" y="317.44" width="0.021" height="18.98"/>
      <rect x="422.68" y="317.44" width="0.021" height="18.98"/>
      <rect x="435.839" y="317.44" width="0.021" height="18.98"/>
      <rect x="449" y="317.44" width="0.02" height="18.98"/>
      <rect x="462.16" y="317.44" width="0.02" height="18.98"/>
      <rect x="475.321" y="317.44" width="0.019" height="18.98"/>
      <rect x="488.48" y="317.44" width="0.02" height="18.98"/>
      <rect x="501.639" y="317.44" width="0.021" height="18.98"/>
      <rect x="514.8" y="317.44" width="0.021" height="18.98"/>
      <!-- start grid period horizontal -->
      <rect class="period-hor" x="39.24" y="366.241" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="396.06" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="415.941" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="435.821" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="465.639" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="495.46" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="515.34" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="535.22" width="70.24" height="1"/>
      <rect class="period-hor" x="39.24" y="574.98" width="70.24" height="1"/>
      <!-- end grid period horizontal -->
      <!-- start grid horizontal period -->
      <rect class="grid-hor-period" x="118.26" y="366.68" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="396.5" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="416.379" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="436.259" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="466.08" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="495.9" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="515.78" width="409.24" height="1"/>
      <rect class="grid-hor-period" x="118.26" y="535.66" width="409.24" height="1"/>
      <!-- end grid horizontal period -->
      <!-- start grid horizontal -->
      <rect class="grid-hor" x="118.26" y="346.80" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="356.74" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="376.62" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="386.56" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="406.44" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="426.32" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="446.20" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="456.14" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="476.02" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="485.96" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="505.84" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="525.72" width="409.24" height="0.2"/>

      <rect class="grid-hor" x="118.26" y="565.48" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="545.60" width="409.24" height="0.2"/>
      <rect class="grid-hor" x="118.26" y="555.54" width="409.24" height="0.2"/>
      <!-- end grid horizontal -->
      <!-- start grid vertical -->
      <rect class="grid-ver" x="133.16" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="146.32" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="159.48" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="172.64" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="185.8" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="198.96" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="212.12" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="225.28" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="238.44" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="251.6" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="264.76" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="277.92" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="291.08" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="304.24" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="317.4" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="330.559" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="343.72" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="356.88" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="370.04" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="383.2" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="396.36" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="409.52" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="422.68" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="435.839" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="449" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="462.16" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="475.321" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="488.48" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="501.639" y="337.32" width="0.5" height="237.661"/>
      <rect class="grid-ver" x="514.8" y="337.32" width="0.5" height="237.661"/>
      <!-- end grid vertical -->
      <rect x="133.16" y="575.88" width="0.02" height="9.04"/>
      <rect x="146.32" y="575.88" width="0.02" height="9.04"/>
      <rect x="159.48" y="575.88" width="0.02" height="9.04"/>
      <rect x="172.64" y="575.88" width="0.021" height="9.04"/>
      <rect x="185.8" y="575.88" width="0.02" height="9.04"/>
      <rect x="198.96" y="575.88" width="0.02" height="9.04"/>
      <rect x="212.12" y="575.88" width="0.02" height="9.04"/>
      <rect x="225.28" y="575.88" width="0.02" height="9.04"/>
      <rect x="238.44" y="575.88" width="0.021" height="9.04"/>
      <rect x="251.6" y="575.88" width="0.02" height="9.04"/>
      <rect x="264.76" y="575.88" width="0.02" height="9.04"/>
      <rect x="277.92" y="575.88" width="0.02" height="9.04"/>
      <rect x="291.08" y="575.88" width="0.021" height="9.04"/>
      <rect x="304.24" y="575.88" width="0.019" height="9.04"/>
      <rect x="317.4" y="575.88" width="0.02" height="9.04"/>
      <rect x="330.559" y="575.88" width="0.021" height="9.04"/>
      <rect x="343.72" y="575.88" width="0.021" height="9.04"/>
      <rect x="356.88" y="575.88" width="0.021" height="9.04"/>
      <rect x="370.04" y="575.88" width="0.019" height="9.04"/>
      <rect x="383.2" y="575.88" width="0.02" height="9.04"/>
      <rect x="396.36" y="575.88" width="0.02" height="9.04"/>
      <rect x="409.52" y="575.88" width="0.021" height="9.04"/>
      <rect x="422.68" y="575.88" width="0.021" height="9.04"/>
      <rect x="435.839" y="575.88" width="0.021" height="9.04"/>
      <rect x="449" y="575.88" width="0.02" height="9.04"/>
      <rect x="462.16" y="575.88" width="0.02" height="9.04"/>
      <rect x="475.321" y="575.88" width="0.019" height="9.04"/>
      <rect x="488.48" y="575.88" width="0.02" height="9.04"/>
      <rect x="501.639" y="575.88" width="0.021" height="9.04"/>
      <rect x="514.8" y="575.88" width="0.021" height="9.04"/>
      <rect x="527.5" y="317.44" width="0.92" height="268.38"/>
      <rect x="38.32" y="336.42" width="0.92" height="239.46"/>
      <rect x="343.72" y="585.82" width="0.021" height="18.979"/>
      <rect x="117.34" y="316.54" width="0.92" height="289.16"/>
      <rect x="133.16" y="585.82" width="0.02" height="18.979"/>
      <rect x="146.32" y="585.82" width="0.02" height="18.979"/>
      <rect x="159.48" y="585.82" width="0.02" height="18.979"/>
      <rect x="172.64" y="585.82" width="0.021" height="18.979"/>
      <rect x="185.8" y="585.82" width="0.02" height="18.979"/>
      <rect x="198.96" y="585.82" width="0.02" height="18.979"/>
      <rect x="212.12" y="585.82" width="0.02" height="18.979"/>
      <rect x="225.28" y="585.82" width="0.02" height="18.979"/>
      <rect x="238.44" y="585.82" width="0.021" height="18.979"/>
      <rect x="251.6" y="585.82" width="0.02" height="18.979"/>
      <rect x="264.76" y="585.82" width="0.02" height="18.979"/>
      <rect x="277.92" y="585.82" width="0.02" height="18.979"/>
      <rect x="291.08" y="585.82" width="0.021" height="18.979"/>
      <rect x="304.24" y="585.82" width="0.019" height="18.979"/>
      <rect x="317.4" y="585.82" width="0.02" height="18.979"/>
      <rect x="330.559" y="585.82" width="0.021" height="18.979"/>
      <rect x="356.88" y="585.82" width="0.021" height="18.979"/>
      <rect x="370.04" y="585.82" width="0.019" height="18.979"/>
      <rect x="383.2" y="585.82" width="0.02" height="18.979"/>
      <rect x="396.36" y="585.82" width="0.02" height="18.979"/>
      <rect x="409.52" y="585.82" width="0.021" height="18.979"/>
      <rect x="422.68" y="585.82" width="0.021" height="18.979"/>
      <rect x="435.839" y="585.82" width="0.021" height="18.979"/>
      <rect x="449" y="585.82" width="0.02" height="18.979"/>
      <rect x="462.16" y="585.82" width="0.02" height="18.979"/>
      <rect x="475.321" y="585.82" width="0.019" height="18.979"/>
      <rect x="488.48" y="585.82" width="0.02" height="18.979"/>
      <rect x="501.639" y="585.82" width="0.021" height="18.979"/>
      <rect x="514.8" y="585.82" width="0.021" height="18.979"/>
      <rect x="527.96" y="585.82" width="0.021" height="18.979"/>
      <rect x="540.66" y="317.44" width="0.921" height="288.26"/>
      <rect x="108.56" y="337.32" width="0.92" height="238.56"/>
      <rect x="39.7" y="27.86" width="304.938" height="1.8"/>
      <rect x="39.7" y="46.72" width="304.938" height="1.8"/>
      <rect x="118.26" y="316.54" width="423.32" height="0.9"/>
      <rect x="528.42" y="326.919" width="12.24" height="0.021"/>
      <rect x="118.26" y="336.42" width="423.32" height="0.9"/>
      <rect x="528.42" y="366.68" width="12.24" height="0.021"/>
      <rect x="528.42" y="396.5" width="12.24" height="0.019"/>
      <rect x="528.42" y="416.379" width="12.24" height="0.021"/>
      <rect x="528.42" y="436.259" width="12.24" height="0.021"/>
      <rect x="528.42" y="466.08" width="12.24" height="0.019"/>
      <rect x="528.42" y="495.9" width="12.24" height="0.02"/>
      <rect x="528.42" y="515.78" width="12.24" height="0.02"/>
      <rect x="528.42" y="535.66" width="12.24" height="0.02"/>
      <rect x="118.26" y="574.98" width="423.32" height="0.899"/>
      <rect x="118.26" y="584.92" width="423.32" height="0.9"/>
      <rect x="118.26" y="595.299" width="422.4" height="0.021"/>
      <rect x="118.26" y="604.8" width="423.32" height="0.9"/>
      <!-- end structural lines for bounding boxes and grid etc. -->

      <image overflow="visible" width="183" height="64" xlink:href="data:image/jpeg;base64,/9j/4AAQSkZJRgABAgEAlgCWAAD/7AARRHVja3kAAQAEAAAAHgAA/+4AIUFkb2JlAGTAAAAAAQMA
        EAMCAwYAAAKfAAAFIAAADIv/2wCEABALCwsMCxAMDBAXDw0PFxsUEBAUGx8XFxcXFx8eFxoaGhoX
        Hh4jJSclIx4vLzMzLy9AQEBAQEBAQEBAQEBAQEABEQ8PERMRFRISFRQRFBEUGhQWFhQaJhoaHBoa
        JjAjHh4eHiMwKy4nJycuKzU1MDA1NUBAP0BAQEBAQEBAQEBAQP/CABEIAEEAuQMBIgACEQEDEQH/
        xACsAAADAQEBAQEAAAAAAAAAAAAFBgcABAMBAgEBAAAAAAAAAAAAAAAAAAAAABAAAQQCAQIFBAMA
        AAAAAAAABQADBAYBAgcQFhETNBU1IFASFzEzNhEAAgECAwMGCAkICwAAAAAAAQIDEQQAEgUQITFB
        UXGRMhNh0SJCkrI1BoGxUnIjcxQ0dCBi0jODk9MkocGCosJDU7PDVBUSAQAAAAAAAAAAAAAAAAAA
        AFD/2gAMAwEAAhEDEQAAACHCx9gofT6yLeYQ5zYPhsokPYAyBdfyJXzh5Q64TLFqlrfOAxg+DBZR
        xcu2T1gW+H9Bjr5eP2DPCaGDmB5BAk9PMyBDyOBBkPz40KIEiOHBPpU1CNlilCOiVOqUELhKaqTk
        NTF4Sj5rhOtUaQgoapronV2RMQ4dfJ4k753ksTBgE8pZY1SZsbdlHJZ9blAsZyUVcG+QkSOCl5+Q
        RGLnwt44j5EF6uf6U8Pzp5U2pQbyXKL2iDinMyyErbEraDIneIQd9wg1qEUPsZi2AnVsU/bEr8tg
        gP2Hhh2FdO2CA/Y7KbsaVbHmxbH/2gAIAQIAAQUA++f/2gAIAQMAAQUA++f/2gAIAQEAAQUANwbn
        IK5F8iYXtfIigkjzAru6yru6yru6yru6yobyIZi7hzMIzEuhs9DO6Wi1b77Wyza57usqj3WyMb1y
        /skHbRKkRAHd1lXd1lXd1lXd1lQvkUtG3FFoZaInh5N0j5D2mkke86mmt2R/bI50y6LYapvWklnB
        pwjF3mlWQElskUzjJPpjOcZ0LOFePPpoRZyCaRx+uv7x805iB7dTFC0itiG5ZjQizOmlw3t8BW2t
        C5AhDMbZI3AWUI2et1o6ycpkOK5FdEjHdbmIjCDaA427FVd113O+3QFcK2LeDoBjbJpWGqBpkzPH
        bMlSON7C0gsSRCr0LebtFPzIoyH+zgqsXIDZEeqKIcInCWGmbFY572IFUukEKP35OEY1OmHjRLGM
        5zsJ3E8eoTLbgk/2cFVkv7ZMeuPxDkwurnKPTiQgBH1ciljjUwY7NeCMxBrxWwV6IPj9MeHjSZId
        4O9N0i2vBiPvkhnxn9KXJDRjFx/zP0a/j+VRkiXw6dmsZeIWsgNIjWafKIOutvR6rLuDj87e2kd/
        1tX1a6NoIiKiktoFglYk6H5sm3Mj6vUoJ2I/xoF3bKDpAuesEtiXHKERGppT9bV9Wykah4q4+JbR
        Dicd08zzDCZdI4d22j7xSIg4824NsESYrAzh8Ghm+WyUyK/KOexXJce6uaClyUzhs8gLmc0RVv59
        WVnD4BAHMtmlML1xuxb2+p67941ND5MaWGLGZBVwFttk0pLfnRt9NtN2tstuWs27GJ/m4uNPgVyi
        xnEjwVfkY7Z8FW/n1Na8+HnXOuYLvkzPd4atv+g6AvgUL+T6S/Vo16hUr4pXn0yGemQb5bo//fj+
        V//aAAgBAgIGPwBz/9oACAEDAgY/AHP/2gAIAQEBBj8AuX0q77qyBQRpmAoe7TNup8quN9+B+0Hi
        x9/H7xfFj3hS+ume8sFQRyAg5GIJOU0x7Rm6x4se0ZuseLHtGbrHix7Ql6x4sAXmW7i86oyvTwEY
        F1ZtUcHQ9pG5mGJ4bC5ljt4o42ZU7K5l4ndhUS9nZ37Cji3RuwVbUJgQaEEjcR8GPaM3WPFjN9sa
        X82QBhhLPUlFvO+5JR+rY8x5sXtzbOYpo0BR14g5lGPaM3WPFj2jN1jxY9ozdY8WPaEvWPFhVvgL
        qHzj2Xp04W7s3zIdzDzlPMRsuZoNSa3gZlywBFalI0BNW58BZn+1mnnZU9UY+jsox4TOw+Jce9sU
        ihXXuwVVi4G4+c284srf7OwtZdOE8hWoBmyk1zYW+kgKXpvO6zsCG7vITSh/IgTN9BdsIZl5PK3K
        3wNj3is4iomntLZI85yitG5caDc5oRHp0AjuqOKl6MN3PxxeEcO/l9c7ajcRi7kmOaeBO4kblORk
        yk9KkflR2pb+XvPo3XkzeaevZc2GoXgtZxIjsUJWSndoRvA4EYnsRqhdbg1MrMTInDstl3cMe2pf
        3jfo496ks5TPbKIxFKxqWFDvrix0uC9yRvp63OcxozAqp8kbuG7GnXl9L3ldVhiMQVQlBy7h4cfd
        4/QGLm5jgSG5t42lSRAFJyCpU04gjZaBe0Zo6dOYYuhp0TymOKEyZCBTMu6tSObFpLfWri1Vj3pc
        grTK3EV58aiZIUcrfzqMyg0Ay7sFJLWJlO4goMPb2oywSIsqJ8nNUFesbNcJ7JdadNI67NPVwGUz
        xgg7wRmGPu8foDFzdxQJDc2yGVJEAWoXeVanHdssQna75Kdey61XULxrQyPHHmJUICI0Ve0OWmK6
        dqsMw5AaN/ShOD3RgnH5jlT/AH1XHvNaXK5J4VjWRag0PlcoxZ3P2OzOom2VYIHly3DQ0p8nm34s
        4qWcaW19FPJa2cmeQFK5vJIXH3a56o/4mJbCwt3iE4yyySkVyHiFCk8dkU5X+XsiJpWPDMOwvSTj
        V9RuHl7ixtYHeGFyhlLCi1Ipwxp+saXc3FtDfd4rW7Ss2VojSoNeXEtteRTTTSzNMXQKQcwUb8zA
        1qMHJa3DNyA5AOvOcSX0yhMwCog4Ki8BgACpO4AYubeYZZ5I++mHMzsvk/AKDZa3koLRwSpIyrTM
        QprurTH3a56o/wCJiSwsIHiScZZZJSM2XmAUnjsW9Zf5ez8oseBc9kbL7R7W2eeyjeF6xxszBu6j
        bew3cuJW94JJ9JRQvcyNGy52JNRUqcG30y8uJauVhRWZs4BNPJ6Me9El+rLdssZmVhlYNRuIONL1
        ttQRDaW0UbW+QkkqjDtf2ubDXsOordvJLTuhGVIDZmrUk8Kbd/DCx6WpjMRpcRvQyZz5zEAVryHG
        pq1xbQd7DbALcgnPQNuUBhw5cCIX2mNk8wKxy/Bn3YuTUGs0hqoovaPAc22N9UUliQLeQ0MSOeBd
        SOo8mNQ+rHrL+SM4JWvlAbjTEa6Uvdxx+TLG1M4flL04159l3a292ltdxyIZCyZ+McZHkkrWow9j
        c266rZFVJljjyHyhvFPLU0xBqdpG+n3kJzmJlaJTuINVIKcvmnHvhLEweNihVlNQdxwkeoRuuni3
        PcsY0AJCjut434s7P3hjdLCa5iQtkRPKYldxUcxOO3cemv6GDqGnyvLboQJo5KFkDbgwIpUV2QJW
        kN39BIOTyuwfSpjXLqwhE2ow2tuLUFQxBeuagPRiynsLFV1G5DtqLrEubMhyx1ru3ri5vNUMq3Yu
        ZEkCMFFQFZqjKd9WOCIJp4pPNYlXAPhXKMTWNzTvYWoSODDirDpGyeWQ5pYo+4kJ4kxuoB9Gmy0t
        JqiKeVI3y7jRjQ0x27j01/Qx/wChYSPLbKQsqSUzJm3BqilRXYtsT9FdgxsOTMN6nZdpZyQx3glT
        ve9+rjpWm/s0pj71Z9TePCm5ubRofPC1DU8FTj3wa2KmElMpTs8DWlPDixfSr/7LAbWLOjzFSXpv
        ND4MadLqV+t1AbyBRGJM/lFtxpsv4iK5reTrClh8Wy0kG4rNGa9DDGvJayGG5FtbdzJmKBWIbeSM
        e1l/f4vElbPKt5KHatczBUqa9OyKUf51uhPSrMvxDZrkdey6mnzsni2ad+Ij9YbNQjO/6B2HSozD
        4tli43ETJ8ey+sdVt445U7thdSAEPWKM5T0VwyjSswUkBgFoaco349kH0V8ePem4tIu4t5FjMcVA
        Moo27diB5FEZt4UgUITvVK0J68WFSSPtEXH542Sxf6iMnpAjDIwoykg9I3YSQcUYN1GuL+KBQ8ep
        2tuGc1qq5cwK06cdo9ZxNX/sv6keywuANzI8ZPhUhh62z3gtT2jHFIB4A2U/1bNO/ER+sNk8A4yx
        unpKRgqRQg0IxBL8iRW6jj9YOvF3+z/2k26z8xP8Wy0+uT1htn+sf1jsg/CweoNkn17eqmy0+sb1
        dmo/hv8AkTZZ/XJ8e2X57fGdv//Z" transform="matrix(0.4796 0 0 0.4734 457.9199 30.6602)">
      </image>

      <text transform="matrix(1 0 0 1 350.502 37.3013)" font-family="'Arial'" font-size="8"><xsl:text>Triple R Broadcasters Ltd. </xsl:text></text>
      <text transform="matrix(1 0 0 1 350.502 46.9014)" font-family="'Arial'" font-size="8"><xsl:text>221 Nicholson St, </xsl:text></text>
      <text transform="matrix(1 0 0 1 350.502 56.501)" font-family="'Arial'" font-size="8"><xsl:text>East Brunswick 3057. </xsl:text></text>
      <text transform="matrix(1 0 0 1 350.502 66.1011)" font-family="'Arial'" font-size="8"><xsl:text>Phone: +61 3 9388 1027 </xsl:text></text>
      <text transform="matrix(1 0 0 1 350.502 75.7012)" font-family="'Arial'" font-size="8"><xsl:text>Fax: +61 3 9388 9079</xsl:text></text>
      <!-- end contract header -->
      <!-- start DETAILS section -->
      <text transform="matrix(1 0 0 1 39.7866 91.2944)" font-family="'Arial'" font-size="9.2"><xsl:text>Details</xsl:text></text>
      <text transform="matrix(1 0 0 1 40.1997 106.5791)" font-family="'Arial'" font-size="8"><xsl:text>Client Name:</xsl:text></text>
      <text transform="matrix(1 0 0 1 110.1069 106.3828)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/name"/></text>
      <text transform="matrix(1 0 0 1 404.7764 106.521)" font-family="'Arial'" font-size="8"><xsl:text>Date:</xsl:text></text>
      <text transform="matrix(1 0 0 1 462.7764 106.3008)" font-family="'Arial'" font-size="8"><xsl:call-template name="format-date"><xsl:with-param name="date"><xsl:value-of select="/traffic/client/contract/createdDateTime"/></xsl:with-param></xsl:call-template></text>
      <text transform="matrix(1 0 0 1 40.1997 118.7007)" font-family="'Arial'" font-size="8"><xsl:text>Client Rep:</xsl:text></text>
      <text transform="matrix(1 0 0 1 110.1069 118.707)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/clientRep/firstName"/> <xsl:value-of select="/traffic/clientRep/lastName"/></text>
      <text transform="matrix(1 0 0 1 404.7764 119.7192)" font-family="'Arial'" font-size="8"><xsl:text>Contract No.:</xsl:text></text>
      <text transform="matrix(1 0 0 1 462.834 119.6797)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/contract/name"/></text>
      <text transform="matrix(1 0 0 1 404.7803 93.2207)" font-family="'Arial'" font-size="8"><xsl:text>Sales Rep:</xsl:text></text>
      <text transform="matrix(1 0 0 1 462.7764 93.1797)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/salesRep/firstName"/> <xsl:value-of select="/traffic/salesRep/lastName"/></text>
      <text transform="matrix(1 0 0 1 40.1997 130.8228)" font-family="'Arial'" font-size="8"><xsl:text>Address:</xsl:text></text>
      <text transform="matrix(1 0 0 1 110.1067 131.4243)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/address"/></text>
      <text transform="matrix(1 0 0 1 356.1143 131.8081)" font-family="'Arial'" font-size="8"><xsl:text>City:</xsl:text></text>
      <text transform="matrix(1 0 0 1 372.8323 131.8081)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/city"/></text>
      <text transform="matrix(1 0 0 1 485.4502 131.8081)" font-family="'Arial'" font-size="8"><xsl:text>Postcode:</xsl:text></text>
      <text transform="matrix(1 0 0 1 525.6506 131.8081)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/postcode"/></text>
      <text transform="matrix(1 0 0 1 40.1914 143.406)" font-family="'Arial'" font-size="8"><xsl:text>Telephone:</xsl:text></text>
      <text transform="matrix(1 0 0 1 110.1067 143.406)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/landline"/></text>
      <text transform="matrix(1 0 0 1 245.8555 143.406)" font-family="'Arial'" font-size="8"><xsl:text>Mobile:</xsl:text></text>
      <text transform="matrix(1 0 0 1 276.5999 143.406)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/mobile"/></text>
      <text transform="matrix(1 0 0 1 410.9277 143.406)" font-family="'Arial'" font-size="8"><xsl:text>Fax:</xsl:text></text>
      <text transform="matrix(1 0 0 1 428.2151 143.406)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/fax"/></text>
      <text transform="matrix(1 0 0 1 383.2207 156)" font-family="'Arial'" font-size="8"><xsl:text>Email:</xsl:text></text>
      <text transform="matrix(1 0 0 1 408.8196 156)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/email"/></text>
      <!-- Change presents status from boolean to yes/no -->
      <xsl:variable name="stationPresentsStatus"><xsl:value-of select="/traffic/client/contract/stationPresentsStatus"/></xsl:variable>
      <xsl:if test="$stationPresentsStatus='true'">
        <text transform="matrix(1 0 0 1 485.4502 181.8081)" font-family="'Arial'" font-size="8"><xsl:text>Presents: Yes</xsl:text></text>
      </xsl:if>

      <text transform="matrix(1 0 0 1 40.1997 160.7217)" font-family="'Arial'" font-size="8"><xsl:text>Campaign Name(s):</xsl:text></text>
        <!-- start Campaign Loop -->
        <text transform="matrix(1 0 0 1 100.2402 174.7217)" font-family="'Arial'" font-size="8"><xsl:for-each select="/traffic/client/contract/campaign"><xsl:value-of select="name"/>,</xsl:for-each></text>
        <!-- end Campaign Loop -->
      <text transform="matrix(1 0 0 1 40.1997 187.0771)" font-family="'Arial'" font-size="8"><xsl:text>Notes:</xsl:text></text>
      <text transform="matrix(1 0 0 1 100.2402 200.7217)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/contract/notes"/></text>
      <!--<text transform="matrix(1 0 0 1 100.2402 200.7217)" font-family="'Arial'" font-size="8"><tspan x="0" dy="-1em"><xsl:call-template name="string_splitter"><xsl:with-param name="original"><xsl:value-of select="/traffic/client/contract/notes"/></xsl:with-param><xsl:with-param name="maxLength" select="'130'"/><xsl:with-param name="separator"></tspan><tspan x="0" dy="-1em"></xsl:with-param><xsl:with-param name="wordWrap" select="'true'"/></xsl:call-template></tspan></text>-->

      <!-- end DETAILS section -->
      <!-- start SCHEDULE section header -->
      <text transform="matrix(1 0 0 1 40.2998 216.98)" font-family="'Arial'" font-size="9.2"><xsl:text>Schedule</xsl:text></text>
      <text transform="matrix(1 0 0 1 100.2402 228.4961)" font-family="'Arial'" font-size="8"><xsl:text>Campaign Audio Details:</xsl:text></text>
      <text transform="matrix(1 0 0 1 40.5186 229.2422)" font-family="'Arial'" font-size="8"><xsl:text>Audio ID</xsl:text></text>
      <text transform="matrix(1 0 0 1 397.7793 229.0801)" font-family="'Arial'" font-size="8"><xsl:text>Start:</xsl:text></text>
      <text transform="matrix(1 0 0 1 476.7373 228.9961)" font-family="'Arial'" font-size="8"><xsl:text>End:</xsl:text></text>

      <xsl:variable name="totalAudio"><xsl:value-of select="count(//campaignAudio[@id])"/></xsl:variable>
      <!-- start Campaign Audio Loop -->
      <xsl:for-each select="/traffic/client/contract/campaign/campaignAudio">
        <!-- Check for new grid time bracket, and assign a y-axis coordinate offset. -->
        <xsl:variable name="count"><xsl:number count="//campaignAudio[@id]"/></xsl:variable>
        <xsl:variable name="spotLetter"><xsl:number count="//campaignAudio[@id]" format="A"/></xsl:variable>
        <xsl:variable name="identifier"><xsl:value-of select="@id"/></xsl:variable>
        <xsl:variable name="audioOffset"><xsl:value-of select="'241.2197' + ('12.12' * ($count - '1'))"/></xsl:variable>

          <xsl:if test="$totalAudio &lt;= 4">
            <xsl:if test="position() &lt;= 4">
              <!-- If four or less audio pieces, list them all -->
              <text font-family="'Arial'" font-size="9"><xsl:attribute name="transform">matrix(1 0 0 1 40.52 <xsl:value-of select="$audioOffset"/>)</xsl:attribute><xsl:number count="//campaignAudio[@id]" format="A"/></text>
              <text font-family="'Arial'" font-size="8"><xsl:attribute name="transform">matrix(1 0 0 1 100.2402 <xsl:value-of select="$audioOffset"/>)</xsl:attribute><xsl:value-of select="name"/></text>
              <text font-family="'Arial'" font-size="8"><xsl:attribute name="transform">matrix(1 0 0 1 397.0498 <xsl:value-of select="$audioOffset"/>)</xsl:attribute><xsl:call-template name="format-date"><xsl:with-param name="date"><xsl:value-of select="startDate"/></xsl:with-param></xsl:call-template></text>
              <text font-family="'Arial'" font-size="8"><xsl:attribute name="transform">matrix(1 0 0 1 476.0498 <xsl:value-of select="$audioOffset"/>)</xsl:attribute><xsl:call-template name="format-date"><xsl:with-param name="date"><xsl:value-of select="endDate"/></xsl:with-param></xsl:call-template></text>
            </xsl:if>
          </xsl:if>
          <xsl:if test="$totalAudio &gt; 4">
            <xsl:if test="position() = 1">
              <!-- If greater than four audio pieces, show audio range -->
              <text font-family="'Arial'" font-size="9"><xsl:attribute name="transform">matrix(1 0 0 1 40.52 241.2197)</xsl:attribute><xsl:number value="'1'" format="A"/>  <xsl:number value="$totalAudio" format="A"/></text>
              <!-- <text font-family="'Arial'" font-size="8"><xsl:attribute name="transform">matrix(1 0 0 1 100.2402 241.2197)</xsl:attribute><xsl:value-of select="name"/></text> -->
              <text font-family="'Arial'" font-size="8"><xsl:attribute name="transform">matrix(1 0 0 1 397.0498 241.2197)</xsl:attribute><xsl:call-template name="format-date"><xsl:with-param name="date"><xsl:value-of select="$startDate"/></xsl:with-param></xsl:call-template></text>
              <text font-family="'Arial'" font-size="8"><xsl:attribute name="transform">matrix(1 0 0 1 476.0498 241.2197)</xsl:attribute><xsl:call-template name="format-date"><xsl:with-param name="date"><xsl:value-of select="$endDate"/></xsl:with-param></xsl:call-template></text>
            </xsl:if>
          </xsl:if>

       <xsl:call-template name="for-loop"><xsl:with-param name="startDate" select="$beginDate"/><xsl:with-param name="slotTime" select="$slotTime"/><xsl:with-param name="spotLetter" select="$spotLetter"/><xsl:with-param name="xoffset" select="'-2'"/><xsl:with-param name="campaignAudioID" select="$identifier"/><xsl:with-param name="i" select="0"/><xsl:with-param name="increment" select="1"/><xsl:with-param name="operator" select="'&lt;'"/><xsl:with-param name="testValue" select="30"/><xsl:with-param name="iteration" select="0"/></xsl:call-template>
       <!-- end Spots Loop -->
      </xsl:for-each>
      <!-- end Campaign Audio Loop -->

      <!-- start Campaign Promotion Loop -->
      <xsl:for-each select="/traffic/client/contract/campaign/campaignPromotion">
        <!-- Check for new grid time bracket, and assign a y-axis coordinate offset. -->
        <xsl:variable name="count"><xsl:number count="//campaignPromotion[@id]"/></xsl:variable>
        <xsl:variable name="spotLetter"><xsl:number count="//campaignPromotion[@id]" format="1"/></xsl:variable>
        <xsl:variable name="identifier"><xsl:value-of select="@id"/></xsl:variable>
        <xsl:variable name="audioOffset"><xsl:value-of select="'241.2197' + ('12.12' * ($count - 1))"/></xsl:variable>

       <xsl:call-template name="for-loop"><xsl:with-param name="startDate" select="$beginDate"/><xsl:with-param name="slotTime" select="$slotTime"/><xsl:with-param name="spotLetter" select="$spotLetter"/><xsl:with-param name="xoffset" select="'0'"/><xsl:with-param name="campaignAudioID" select="$identifier"/><xsl:with-param name="i" select="0"/><xsl:with-param name="increment" select="1"/><xsl:with-param name="operator" select="'&lt;'"/><xsl:with-param name="testValue" select="30"/><xsl:with-param name="iteration" select="0"/></xsl:call-template>

       <!-- end Spots Loop -->
      </xsl:for-each>
      <!-- end Campaign Promotion Loop -->

      <text transform="matrix(1 0 0 1 39.2402 294.6064)" font-family="'Arial'" font-size="8"><xsl:text>Audio Purchased:</xsl:text></text>
      <text transform="matrix(1 0 0 1 110.2402 294.6064)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/contract/audioPurchased"/></text>
      <text transform="matrix(1 0 0 1 155.1421 294.6064)" font-family="'Arial'" font-size="8"><xsl:text>Spots Purchased:</xsl:text></text>
      <text transform="matrix(1 0 0 1 225.3398 294.6064)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/contract/spotsPurchased"/></text>-->

      <!-- Sector and Product Type from the contract -->
      <text transform="matrix(1 0 0 1 269.1631 294.6064)" font-family="'Arial'" font-size="8"><xsl:text>Client Sector:</xsl:text></text>
      <text transform="matrix(1 0 0 1 323.5635 294.6064)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/sector/name"/></text>
      <text transform="matrix(1 0 0 1 401.3018 294.6064)" font-family="'Arial'" font-size="8"><xsl:text>Product Type:</xsl:text></text>
      <text transform="matrix(1 0 0 1 457.2598 294.6064)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/contract/campaign/campaignAudio/productType"/></text>

      <text transform="matrix(1 0 0 1 110 312)" font-family="'Arial'" font-size="8" font-style="italic">
	    <xsl:text>A - Z denotes on air announcements</xsl:text>
	    <xsl:text>1 denotes live read giveaway</xsl:text>
	  </text>

      <!-- end SCHEDULE section header -->

      <!-- start SCHEDULE traffic table -->
      <!-- Create the grid date header and footer. -->
      <xsl:call-template name="grid-header"><xsl:with-param name="startDate" select="$beginDate"/><xsl:with-param name="yTopRow" select="'324.3398'"/><xsl:with-param name="yBotRow" select="'333.5801'"/></xsl:call-template>
      <xsl:call-template name="grid-header"><xsl:with-param name="startDate" select="$beginDate"/><xsl:with-param name="yTopRow" select="'602.6602'"/><xsl:with-param name="yBotRow" select="'592.0195'"/></xsl:call-template>

      <text class="period" transform="matrix(1 0 0 1 74.36 349.3257)" font-family="'Arial'" font-size="7" text-anchor="middle">Breakfast</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 358.6875)" font-family="'Arial'" font-size="7" text-anchor="middle">6-9 AM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 379.1401)" font-family="'Arial'" font-size="7" text-anchor="middle">Morning</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 388.502)" font-family="'Arial'" font-size="7" text-anchor="middle">9-12 AM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 403.9805)" font-family="'Arial'" font-size="7" text-anchor="middle">Lunch</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 413.3418)" font-family="'Arial'" font-size="7" text-anchor="middle">12-2 PM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 423.8604)" font-family="'Arial'" font-size="7" text-anchor="middle">Afternoon</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 433.2227)" font-family="'Arial'" font-size="7" text-anchor="middle">2-4 PM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 448.7227)" font-family="'Arial'" font-size="7" text-anchor="middle">Drivetime</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 458.084)" font-family="'Arial'" font-size="7" text-anchor="middle">4-7 PM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 478.5449)" font-family="'Arial'" font-size="7" text-anchor="middle">Early evening</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 487.9072)" font-family="'Arial'" font-size="7" text-anchor="middle">7-10 PM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 503.3848)" font-family="'Arial'" font-size="7" text-anchor="middle">Late evening</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 512.7471)" font-family="'Arial'" font-size="7" text-anchor="middle">10-12 midnight</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 523.2598)" font-family="'Arial'" font-size="7" text-anchor="middle">Night time</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 532.6221)" font-family="'Arial'" font-size="7" text-anchor="middle">12 mnight-2 AM</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 553.082)" font-family="'Arial'" font-size="7" text-anchor="middle">Graveyard</text>
      <text class="period" transform="matrix(1 0 0 1 74.36 562.4443)" font-family="'Arial'" font-size="7" text-anchor="middle">2-6 AM</text>
      <!-- end SCHEDULE traffic table -->
      <!-- start SCHEDULE section footer -->
      <!-- Moved these up above the grid
      <text transform="matrix(1 0 0 1 40.1421 626.0977)" font-family="'Arial'" font-size="8"><xsl:text>Spots Purchased:</xsl:text></text>
      <text transform="matrix(1 0 0 1 117.3398 625.8145)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/client/contract/spotsPurchased"/></text>-->

      <!-- start hiding of terms and conditions and agreement until the last page -->
      <xsl:if test="$page = $pages">
        <text transform="matrix(1 0 0 1 213.5342 625.5488)" font-family="'Arial'" font-size="8"><xsl:text>Cost:</xsl:text></text>
        <text transform="matrix(1 0 0 1 236.0137 625.5488)" font-family="'Arial'" font-size="8">$ <xsl:value-of select="floor(/traffic/client/contract/price * 100) div 100"/></text>
        <text transform="matrix(1 0 0 1 318.8145 625.5488)" font-family="'Arial'" font-size="8"><xsl:text>GST:</xsl:text></text>
        <text transform="matrix(1 0 0 1 342.291 625.5488)" font-family="'Arial'" font-size="8">$ <xsl:value-of select="floor((/traffic/client/contract/priceGST - /traffic/client/contract/price) * 100) div 100"/></text>
        <text transform="matrix(1 0 0 1 424.0771 625.5488)" font-family="'Arial'" font-size="8"><xsl:text>Total Cost:</xsl:text></text>
        <text transform="matrix(1 0 0 1 464.5146 625.5488)" font-family="'Arial'" font-size="8">$ <xsl:value-of select="floor(/traffic/client/contract/priceGST * 100) div 100"/></text>
        <!-- start END section footer -->
        <!-- start signature footer -->
        <text transform="matrix(1 0 0 1 40.2002 720.5947)" font-family="'Arial'" font-size="8.46"><xsl:text>Client Rep Signature:</xsl:text></text>
        <text transform="matrix(1 0 0 1 40.2002 746.6523)" font-family="'Arial'" font-size="8.46"><xsl:text>Client Rep Title:</xsl:text></text>
        <text transform="matrix(1 0 0 1 404.7246 720.5947)" font-family="'Arial'" font-size="8.46"><xsl:text>With thanks,</xsl:text></text>
        <text transform="matrix(1 0 0 1 404.752 736.8945)" font-family="'Arial'" font-size="8"><xsl:value-of select="/traffic/salesRep/firstName"/> <xsl:value-of select="/traffic/salesRep/lastName"/></text>
        <text transform="matrix(1 0 0 1 404.6602 752.0742)" font-family="'Arial'" font-size="6.58"><xsl:text>Authorised representative of</xsl:text></text>
        <text transform="matrix(1 0 0 1 404.6602 762.0742)" font-family="'Arial'" font-size="6.58"><xsl:value-of select="/traffic/ORG_NAME"/></text>
        <!-- end signature footer -->
        <!-- start terms of contract -->
        <text transform="matrix(1 0 0 1 40.1401 637.1602)" font-family="'Arial'" font-size="6.44">I, the undersigned sponsor agree to pay <xsl:value-of select="/traffic/ORG_TRADING"/> (the &#x201C;Broadcaster&#x201D;) the amount set out in this Contract in consideration of the Broadcaster broadcasting the </text>
        <text transform="matrix(1 0 0 1 40.1401 645.4609)" font-family="'Arial'" font-size="6.44">sponsorship announcements detailed in this Contract. I warrant that I have the rights to use the Business name and Trademark or Tradename which identifies the goods and services in </text>
        <text transform="matrix(1 0 0 1 40.1401 653.7627)" font-family="'Arial'" font-size="6.44">such sponsorship announcements, and that I am authorised and entitled to publicise such business and products referred to in such sponsorship. I hereby indemnify the Broadcaster </text>
        <text transform="matrix(1 0 0 1 40.1401 662.0635)" font-family="'Arial'" font-size="6.44">against any demand, claims, costs, damages, expenses or liability whatsoever arising directly or indirectly from, caused by, or connected with the broadcasting of the sponsorship </text>
        <text transform="matrix(1 0 0 1 40.1401 670.3604)" font-family="'Arial'" font-size="6.44">material set out in this Contract. The Broadcaster reserves the right to cancel this Agreement at any time prior to broadcasting. The Broadcaster will not be liable for errors or </text>
        <text transform="matrix(1 0 0 1 40.1401 679.5137)" font-family="'Arial'" font-size="6.44">omissions in the broadcasting of sponsorship material. The Broadcaster reserves the right to reject sponsors or material incompatible with the station brand or objectives.</text>
        <text transform="matrix(1 0 0 1 40.1401 696.5537)" font-family="'Arial'" font-size="6.44">Contract payment terms are strictly 7 days net. A minimum of 10 spots are required for all campaigns. 48 hours notice is required for all bookings. Invoices are forwarded </text>
        <text transform="matrix(1 0 0 1 40.1401 705.0752)" font-family="'Arial'" font-size="6.44">at the start of the campaigns. A fixed cancellation / new audio fee is $50 per audio piece. All new accounts must pre-pay their first campaigns. This quote is valid for 7 days.</text>
        <!-- end terms of contract -->
      </xsl:if>
      <!-- end hiding of terms and conditions and agreement until the last page -->
      <text text-anchor="end" transform="matrix(1 0 0 1 540 760)" font-family="'Arial'" font-size="8"><xsl:text>Page </xsl:text><xsl:value-of select="$page"/><xsl:text> of </xsl:text><xsl:value-of select="$pages"/></text>
    </svg>
  </xsl:template>

  <!-- Template that creates a new row in the spot grid -->
  <xsl:template name="spotrow">
    <xsl:param name="yaxis"/>
    <xsl:param name="startDate"/>
    <xsl:param name="slotTime"/>
    <xsl:param name="spotLetter"/>
    <xsl:param name="xoffset"/>
    <xsl:param name="campaignAudioID"/>

    <xsl:for-each select="spot">

      <!-- Offset the visual display of 12AM-5AM spots by a day, to reflect the 6-6AM programming day. -->
 	  <xsl:variable name="initialDate">
        <xsl:choose>
          <xsl:when test="(date:hour-in-day($slotTime)) >= (date:hour-in-day('00:00:00')) and (date:hour-in-day($slotTime)) &lt; (date:hour-in-day('06:00:00'))">
		    <xsl:value-of select="date:add(date:date($startDate), 'P1D')"/>
          </xsl:when>
          <xsl:otherwise>
		    <xsl:value-of select="$startDate"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <xsl:choose>
        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P0D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('126.00' + $xoffset)"/><xsl:text> </xsl:text><xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P1D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
              <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('139.1833' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P2D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="(('152.3666' + $xoffset))"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P3D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('165.5499' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P4D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('178.7332' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P5D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('191.9165' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P6D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('205.0998' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P7D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('218.2831' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P8D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('231.4664' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P9D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('244.6497' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P10D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('257.833' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P11D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('271.0163' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P12D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('284.1996' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P13D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('297.3829' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P14D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('310.5662' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P15D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('323.7495' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P16D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('336.9328' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P17D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('350.1161' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P18D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('363.2994' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P19D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('376.4827' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P20D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('389.666' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P21D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('402.8493' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P22D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('416.0326' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P23D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('429.2159' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P24D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('442.3992' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P25D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('455.5825' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P26D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('468.7658' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P27D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('481.9491' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P28D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('495.1324' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P29D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('508.3157' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

        <xsl:when test="@dateTime=concat(date:add(date:date($initialDate), 'P30D'),' ',$slotTime)">
          <xsl:if test="contains($campaignAudioID, @refid)">
            <text font-family="'Arial'" font-size="8" text-anchor="middle">
            <xsl:attribute name="transform">matrix(1 0 0 1 <xsl:value-of select="('521.499' + $xoffset)"/><xsl:text> </xsl:text> <xsl:value-of select="$yaxis"/>)</xsl:attribute><xsl:value-of select="$spotLetter"/></text>
          </xsl:if>
        </xsl:when>

      </xsl:choose>
    </xsl:for-each>
  </xsl:template>

  <!-- Template that runs for every spot to determine where it goes on the grid -->
  <xsl:template name="for-loop">
    <xsl:param name="startDate"/>
    <xsl:param name="slotTime"/>
    <xsl:param name="spotLetter"/>
    <xsl:param name="xoffset"/>
    <xsl:param name="campaignAudioID"/>
    <xsl:param name="i"/>
    <xsl:param name="increment"/>
    <xsl:param name="operator"/>
    <xsl:param name="testValue"/>
    <xsl:param name="iteration"/>

    <xsl:variable name="testPassed">
      <xsl:choose>
        <xsl:when test="starts-with($operator, '!=')">
          <xsl:if test="$i != $testValue">
            <xsl:text>true</xsl:text>
          </xsl:if>
        </xsl:when>
        <xsl:when test="starts-with($operator, '&lt;=')">
          <xsl:if test="$i &lt;= $testValue">
            <xsl:text>true</xsl:text>
        </xsl:if>
        </xsl:when>
        <xsl:when test="starts-with($operator, '>=')">
          <xsl:if test="$i >= $testValue">
            <xsl:text>true</xsl:text>
          </xsl:if>
        </xsl:when>
        <xsl:when test="starts-with($operator, '=')">
          <xsl:if test="$i = $testValue">
            <xsl:text>true</xsl:text>
          </xsl:if>
        </xsl:when>
        <xsl:when test="starts-with($operator, '&lt;')">
          <xsl:if test="$i &lt; $testValue">
            <xsl:text>true</xsl:text>
          </xsl:if>
        </xsl:when>
        <xsl:when test="starts-with($operator, '>')">
          <xsl:if test="$i > $testValue">
            <xsl:text>true</xsl:text>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:message terminate="yes">
            <xsl:text>Sorry, the forloop emulator only </xsl:text>
            <xsl:text>handles six operators </xsl:text>
            <xsl:value-of select="$newline"/>
            <xsl:text>(&lt; | > | = | &lt;= | >= | !=). </xsl:text>
            <xsl:text>The value </xsl:text>
            <xsl:value-of select="$operator"/>
            <xsl:text> is not allowed.</xsl:text>
            <xsl:value-of select="$newline"/>
          </xsl:message>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:if test="$testPassed='true'">
      <!-- Put your logic here, whatever it might be. For the purpose      -->
      <!-- of our example, we'll just write some text to the output stream. -->

      <!-- Define variables for the next spot row -->
        <!-- Add an hour to the slot time and then remove a trailing z from the end. -->
      <xsl:variable name="adjustedTime" select="date:time(date:add(concat(date:date($startDate),'T',date:time($slotTime)), 'PT1H'))"/>
      <xsl:variable name="newTime">
        <xsl:call-template name="time-strip-z">
          <xsl:with-param name="time" select="$adjustedTime"/>
        </xsl:call-template>
      </xsl:variable>

      <!-- Check for new grid time bracket, and assign a y-axis coordinate offset. -->
      <xsl:variable name="yoffset">
        <xsl:choose>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('06:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('07:00:00'))">0</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('07:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('08:00:00'))">9.94</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('08:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('09:00:00'))">19.88</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('09:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('10:00:00'))">29.82</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('10:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('11:00:00'))">39.76</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('11:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('12:00:00'))">49.7</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('12:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('13:00:00'))">59.64</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('13:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('14:00:00'))">69.58</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('14:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('15:00:00'))">79.52</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('15:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('16:00:00'))">89.46</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('16:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('17:00:00'))">99.40</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('17:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('18:00:00'))">109.34</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('18:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('19:00:00'))">119.28</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('19:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('20:00:00'))">129.22</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('20:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('21:00:00'))">139.16</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('21:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('22:00:00'))">149.10</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('22:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('23:00:00'))">159.04</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('23:00:00'))">168.98</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('00:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('01:00:00'))">178.92</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('01:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('02:00:00'))">188.86</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('02:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('03:00:00'))">198.80</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('03:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('04:00:00'))">208.74</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('04:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('05:00:00'))">218.68</xsl:when>
          <xsl:when test="(date:hour-in-day($newTime)) >= (date:hour-in-day('05:00:00')) and (date:hour-in-day($newTime)) &lt; (date:hour-in-day('06:00:00'))">228.62</xsl:when>
        </xsl:choose>
      </xsl:variable>
      <!-- Create the next spot row -->
      <xsl:call-template name="spotrow" match="/traffic/client/contract/campaign/campaignAudio/@id=$campaignAudioID">
        <xsl:with-param name="yaxis" select="'345.7255' + $yoffset"/>
        <xsl:with-param name="startDate" select="$startDate"/>
        <xsl:with-param name="slotTime" select="$newTime"/>
        <xsl:with-param name="spotLetter" select="$spotLetter"/>
        <xsl:with-param name="xoffset" select="$xoffset"/>
        <xsl:with-param name="campaignAudioID" select="$campaignAudioID"/>
      </xsl:call-template>

      <!-- Your logic should end here; don't change the rest of this        -->
      <!-- template!                                                        -->

      <!-- Now for the important part: we increment the index variable and  -->
      <!-- loop. Notice that we're passing the incremented value, not      -->
      <!-- changing the variable itself.                                   -->

      <xsl:call-template name="for-loop">
        <xsl:with-param name="startDate" select="$startDate"/>
        <xsl:with-param name="slotTime"  select="$newTime"/>
        <xsl:with-param name="spotLetter" select="$spotLetter"/>
        <xsl:with-param name="xoffset" select="$xoffset"/>
        <xsl:with-param name="campaignAudioID" select="$campaignAudioID"/>
        <xsl:with-param name="i"         select="$i + $increment"/>
        <xsl:with-param name="increment" select="$increment"/>
        <xsl:with-param name="operator"  select="$operator"/>
        <xsl:with-param name="testValue" select="$testValue"/>
        <xsl:with-param name="iteration" select="$iteration + 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!-- Template that strips the trailing 'z' after a time transformation off the string. -->
  <xsl:template name="time-strip-z">
    <xsl:param name="time"/>
    <xsl:choose>
      <xsl:when test="contains($time, 'Z')">
        <xsl:call-template name="time-strip-z">
          <xsl:with-param name="time" select="substring-before($time,'Z')"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$time"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Template that strips the 'P' and 'D' in a date difference transformation from the string. -->
  <xsl:template name="day-difference-strip">
    <xsl:param name="difference"/>
    <xsl:choose>
      <xsl:when test="contains($difference, 'D')">
        <xsl:call-template name="day-difference-strip">
          <xsl:with-param name="difference" select="substring-before($difference,'D')"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:when test="contains($difference, 'P')">
        <xsl:call-template name="day-difference-strip">
          <xsl:with-param name="difference" select="substring-after($difference,'P')"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$difference"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Template that forms the date header for the spot grid. -->
  <xsl:template name="grid-header">
    <xsl:param name="yTopRow"/>
    <xsl:param name="yBotRow"/>
    <xsl:param name="startDate"/>

    <!-- START GRID HEADER -->

    <!-- Month Name -->
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 112.2202 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">9.2</xsl:attribute><xsl:attribute name="text-anchor">end</xsl:attribute><xsl:value-of select="date:month-abbreviation(date:date($startDate))"/>
    </text>

    <!-- Day of Month -->
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 126.0000 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P0D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 139.1833 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P1D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 152.3666 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P2D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 165.5499 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P3D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 178.7332 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P4D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 191.9165 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P5D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 205.0998 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P6D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 218.2831 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P7D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 231.4664 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P8D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 244.6497 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P9D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 257.833 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P10D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 271.0163 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P11D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 284.1996 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P12D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 297.3829 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P13D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 310.5662 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P14D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 323.7495 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P15D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 336.9328 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P16D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 350.1161 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P17D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 363.2994 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P18D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 376.4827 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P19D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 389.666 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P20D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 402.8493 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P21D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 416.0326 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P22D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 429.2159 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P23D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 442.3992 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P24D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 455.5825 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P25D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 468.7658 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P26D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 481.9491 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P27D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 495.1324 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P28D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 508.3157 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P29D'))"/>
    </text>
    <text>
    <xsl:attribute name="transform">matrix(1 0 0 1 521.499 <xsl:value-of select="$yTopRow"/>)</xsl:attribute><xsl:attribute name="font-family">'Arial'</xsl:attribute><xsl:attribute name="font-size">7</xsl:attribute><xsl:attribute name="text-anchor">middle</xsl:attribute><xsl:value-of select="date:day-in-month(date:add(date:date($startDate), 'P30D'))"/>
    </text>

    <!-- Day of Week -->
    <text font-family="'Arial'" font-size="7">
    <xsl:attribute name="transform">matrix(1 0 0 1 532.7402 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>T</text>

    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 126 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P0D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 139.1833 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P1D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 152.3666 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P2D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 165.5499 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P3D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 178.7332 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P4D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 191.9165 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P5D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 205.0998 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P6D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 218.2831 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P7D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 231.4664 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P8D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 244.6497 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P9D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 257.833 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P10D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 271.0163 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P11D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 284.1996 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P12D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 297.3829 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P13D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 310.5662 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P14D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 323.7495 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P15D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 336.9328 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
    <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P16D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 350.1161 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P17D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 363.2994 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P18D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 376.4827 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P19D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 389.666 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P20D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 402.8493 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P21D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 416.0326 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P22D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 429.2159 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P23D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 442.3992 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P24D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 455.5825 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P25D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 468.7658 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P26D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 481.9491 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P27D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 495.1324 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P28D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 508.3157 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P29D'))"/>
    </text>
    <text font-family="'Arial'" font-size="7" text-anchor="middle">
    <xsl:attribute name="transform">matrix(0.9 0 0 1 521.499 <xsl:value-of select="$yBotRow"/>)</xsl:attribute>
        <xsl:value-of select="date:day-abbreviation(date:add(date:date($startDate), 'P30D'))"/>
    </text>

    <!-- END GRID HEADER -->
  </xsl:template>

  <!-- Template that runs the svg template for the required number of page numbers. -->
  <xsl:template name="generate-pages">
    <xsl:param name="pageNumber"/>
    <xsl:if test="$pageNumber &lt;= $pages">
        <xsl:call-template name="svg"><xsl:with-param name="beginDate"><xsl:value-of select="date:add($startDate, concat('P',(($pageNumber * 31) - 31),'D'))"/></xsl:with-param><xsl:with-param name="page" select="$pageNumber"/></xsl:call-template>
      <xsl:call-template name="generate-pages"><xsl:with-param name="pageNumber" select="$pageNumber + 1"/></xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!-- Template that turns a CCYY-MM-DD date into dd-mmm-CCYY for human-readable output. -->
  <xsl:template name="format-date">
    <xsl:param name="date"/>
    <xsl:choose>
      <xsl:when test="contains($date, ' ')">
        <xsl:call-template name="format-date">
          <xsl:with-param name="date">
            <xsl:call-template name="date-strip-time">
              <xsl:with-param name="dateTimeStamp" select="$date"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
          <xsl:value-of select="concat(date:day-in-month($date),'-',date:month-abbreviation($date),'-',date:year($date))"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Template that strips the time from a PHP-derived datetime stamp. -->
  <xsl:template name="date-strip-time">
    <xsl:param name="dateTimeStamp"/>
    <xsl:choose>
      <xsl:when test="contains($dateTimeStamp, ' ')">
        <xsl:call-template name="date-strip-time">
          <xsl:with-param name="dateTimeStamp" select="substring-before($dateTimeStamp,' ')"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$dateTimeStamp"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>



  <!-- This template returns a string that is splitted according
       to a maximal length of characters.
       Input parameters:
           original (mandatory): original string that must be splitted
           maxLength (mandatory): maximum length before a split
           separator (mandatory): separator that must be used to split the string
           wordWrap (optional): set this value to 'true' if a word must keep together
                                  instead of splitting a word in the middle, there will
                                  be split before the word. Note that when the word is
                                  longer than the maximal length, it's impossible to
                                  keep the word together.
  -->
  <xsl:template name="string_splitter">
    <xsl:param name="original"/>
    <xsl:param name="maxLength"/>
    <xsl:param name="separator"/>
    <xsl:param name="wordWrap"/>
    <xsl:choose>
      <xsl:when test="string-length($original)>$maxLength">
        <xsl:variable name="length-substring">
          <xsl:choose>
            <xsl:when test="$wordWrap='true'">
              <xsl:call-template name="lastCharPosition">
                <xsl:with-param name="original" select="substring($original,1,$maxLength)"/>
                <xsl:with-param name="character" select="' '"/>
              </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$maxLength"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:value-of select="concat(substring($original,1,$length-substring),$separator)"/>
        <xsl:call-template name="string_splitter">
          <xsl:with-param name="original" select="substring($original,$length-substring+1,string-length($original))"/>
          <xsl:with-param name="maxLength" select="$maxLength"/>
          <xsl:with-param name="separator" select="$separator"/>
          <xsl:with-param name="wordWrap" select="'true'"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$original"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- This template returns the position of the last
       given character in the string that can be found. When
       the character is not available in the string, the
       position of the last character is returned.
       Input parameters:
          original (mandatory): original string in which the character must be searched
          character(mandatory): character for which the last position must be returned
  -->
  <xsl:template name="lastCharPosition">
    <xsl:param name="original"/>
    <xsl:param name="character"/>
    <xsl:param name="string_length"/>
    <xsl:variable name="len">
      <xsl:choose>
        <xsl:when test="$string_length">
          <xsl:value-of select="$string_length"/>
        </xsl:when>
        <xsl:otherwise>
                  <xsl:value-of select="'0'"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="char_len">
      <xsl:value-of select="string-length($character)"/>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="contains($original,$character)">
        <xsl:choose>
          <xsl:when test="contains(substring-after($original,$character),$character)">
            <xsl:call-template name="lastCharPosition">
              <xsl:with-param name="original" select="substring-after($original,$character)"/>
              <xsl:with-param name="character" select="$character"/>
              <xsl:with-param name="string_length" select="string-length(concat(substring-before($original,$character),''))+$len"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="string-length(substring-before($original,$character))+$char_len+$len"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="string-length($original)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>







  <xsl:template name="textwrap">
    <xsl:param name="Text"/>
    <xsl:choose>
      <xsl:when test="string-length($Text) &gt; 30">
        <xsl:value-of select="substring($Text, 1, 30)"/>
        <br/>
        <xsl:call-template name="textwrap">
          <xsl:with-param name="Text" select="substring($Text, 31)" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise><xsl:value-of select="$Text"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
